@@ -615,6 +615,7 @@ gkrellm_alloc_chartdata(Chart *cp)
 	cp->alloc_width = w;
 	cp->maxval = 0;
 	cp->scale_max = 0;
+	cp->redraw_all = TRUE;
 	}
 
 static void
@@ -1596,7 +1597,7 @@ static gint		map_125_table[] =
 
 static gint		map_12357_table[] =
 	{
-	1, 2, 5, 7,
+	1, 2, 3, 5, 7,
 	10, 15, 20, 30, 50, 70,
 	100, 150, 200, 300, 500, 700,
 	1000, 1500, 2000, 3000, 5000, 7000,
@@ -1967,7 +1968,7 @@ set_resolution_menubar_items_sensitivity(ChartConfig *cf)
 	else	/* Auto number of grids, auto res always sticks at base value */
 		{
 		GTK_CHECK_MENU_ITEM(w)->active = cf->fixed_grids ?
-				cf->auto_resolution_stick : TRUE;
+				cf->auto_resolution_stick : FALSE;
 		gtk_widget_set_sensitive(w, FALSE);
 		}
 
