@@ -291,9 +291,8 @@ assign_style(gchar *debug_name, GList *style_list, gint index,
 	GList	*list;
 
 	style = (Style *) g_list_nth_data(style_list, index);
-	if (style == NULL)
-		printf(_("Bad assign style for %s, index=%d, arg=%s\n"),
-				debug_name, index, arg);
+	if (!style)
+		return;
 
 	/* If this is not an override assignment and this entry has already had
 	|  an override assignment, then we do not assign.
@@ -308,22 +307,14 @@ assign_style(gchar *debug_name, GList *style_list, gint index,
 	if (index++ == 0)		/* style == style_list */
 		{
 		if (override)
-			printf(_("Bad override on DEFAULT: %s %s %d\n"),
+			printf("Bad override on DEFAULT: %s %s %d\n",
 					debug_name, arg, entry_flag);
-		if (GK.debug_level & DEBUG_STYLES)
-			printf(_("  propagating %s %d: "), arg, entry_flag);
 		for (list = style_list->next; list; list = list->next, ++index)
 			{
 			style = (Style *) list->data;
 			if (style && !(style->override & BIT(entry_flag)))
-				{
-				if (GK.debug_level & DEBUG_STYLES)
-					printf("%d ", index);
 				assign_style_entry(style, arg, entry_flag);
-				}
 			}
-		if (GK.debug_level & DEBUG_STYLES)
-			printf("\n");
 		}
 	}
 
@@ -388,8 +379,6 @@ assign_gkrellmrc_style(gchar *source_line, gchar *area, gchar *string)
 		++arg;
 	scope = strtok(target, ".");
 	entry = strtok(NULL, " \n");
-	if (GK.debug_level & DEBUG_STYLES)
-		printf(_("Assign style: %s %s.%s = %s "), area, scope, entry, arg);
 
 	override = TRUE;
 	style_id = -1;
@@ -430,14 +419,9 @@ assign_gkrellmrc_style(gchar *source_line, gchar *area, gchar *string)
 			entry_flag = sm->value;
 			break;
 			}
-	if (GK.debug_level & DEBUG_STYLES)
-		printf(" (%d %d %d)\n", style_id, entry_flag, override);
 
 	if (entry_flag >= 0 && style_id >= 0)
 		assign_style(area, style_list, style_id, arg, entry_flag, override);
-	else if (GK.debug_level & DEBUG_STYLES)
-		printf(_("\nUnknown %s.%s in line:\n    %s\n"),
-			   scope, entry, source_line);
 	}
 
 gint
@@ -505,11 +489,7 @@ set_image_borders_in_list(GList *st_list, GList *im_list, GList *nm_list)
 		style = (Style *) st_list->data;
 		image = (GdkImlibImage *) im_list->data;
 		if (style && image)
-			{
-			if (GK.debug_level & DEBUG_STYLES)
-				printf(_("Setting border: %s\n"), (gchar *) nm_list->data);
 			gdk_imlib_set_image_border(image, &style->border);
-			}
 		}
 	}
 
@@ -694,15 +674,12 @@ gkrellm_load_image(gchar *name, gchar **xpm, GdkImlibImage **image,
 		gchar *subdir)
 	{
 	GdkImlibImage	*im		= NULL;
-	gchar			*fname,
-					*source = "",
-					*debug_action = _("Loading  ");
+	gchar			*fname;
 
 	if (gkrellm_using_default_theme() && name && subdir)
 		im = default_theme_extension_image(name, subdir);
 	else if (name && (fname = gkrellm_theme_file_exists(name, subdir)) != NULL)
 		{
-		source = _("file image");
 		name = fname;
 		im = gdk_imlib_load_image(fname);
 		if (im == NULL)
@@ -710,7 +687,6 @@ gkrellm_load_image(gchar *name, gchar **xpm, GdkImlibImage **image,
 		}
 	if (im == NULL && xpm)
 		{
-		source = _("xpm image");
 		im = gdk_imlib_create_image_from_xpm_data(xpm);
 		if (im == NULL)
 			printf(_("  Cannot load xpm: %s\n"), name);
@@ -718,13 +694,7 @@ gkrellm_load_image(gchar *name, gchar **xpm, GdkImlibImage **image,
 	if (im && image)
 		{
 		if (*image)
-			{
-			debug_action = _("Replacing");
 			gdk_imlib_kill_image(*image);
-			}
-		if (GK.debug_level & DEBUG_IMAGES)
-			printf("  %s (%s) %s: %s\n", debug_action, subdir ? subdir :"BASE",
-					source, name);
 		*image = im;
 		}
 	return (im ? TRUE : FALSE);
@@ -752,23 +722,17 @@ load_monitor_specific_images(void)
 	{
 	Monitor	*mon;
 	GList	*list;
-	gchar	*subdir, *type;
+	gchar	*subdir;
 	gint	i;
 
-	if (GK.debug_level & DEBUG_IMAGES)
-		printf(_("====>Loading monitor specific theme images.<====\n"));
-
 	for (list = gkrellm_monitor_list; list; list = list->next)
 		{
 		mon = (Monitor *) list->data;
 		if ((subdir = mon->privat->style_name) == NULL)
 			continue;
 		i = mon->privat->style_id;
-		type = (MONITOR_ID(mon) == MON_PLUGIN) ? "plugin " : "builtin";
 		if (mon->privat->style_type == CHART_PANEL_TYPE)
 			{
-			if (GK.debug_level & DEBUG_IMAGES)
-				printf(_("Checking %s chart monitor: %s\n"), type, subdir);
 			load_from_image_list("bg_chart", GK.bg_chart_image_list, i,subdir);
 			load_from_image_list("bg_grid", GK.bg_grid_image_list, i, subdir);
 			load_from_image_list("bg_panel", GK.bg_panel_image_list, i,subdir);
@@ -776,8 +740,6 @@ load_monitor_specific_images(void)
 			}
 		else
 			{
-			if (GK.debug_level & DEBUG_IMAGES)
-				printf(_("Checking %s meter monitor: %s\n"), type, subdir);
 			load_from_image_list("krell", GK.krell_meter_image_list, i,subdir);
 			load_from_image_list("bg_panel", GK.bg_meter_image_list, i,subdir);
 			load_from_image_list("bg_meter", GK.bg_meter_image_list, i,subdir);
@@ -865,8 +827,6 @@ clean_base_image_table(void)
 	for (i = 0; i < sizeof(base_theme_images) / sizeof(ImageTable); ++i, ++ti)
 		if (ti->xpm == NULL && ti->im && *(ti->im))	/* Is an optional image */
 			{
-			if (GK.debug_level & DEBUG_IMAGES)
-				printf(_("Killing image from table: %s\n"), ti->name);
 			gdk_imlib_kill_image(*(ti->im));
 			*(ti->im) = NULL;
 			}
@@ -924,8 +884,6 @@ load_theme_images(void)
 	kill_monitor_specific_images();
 
 	clean_base_image_table();
-	if (GK.debug_level & DEBUG_IMAGES)
-		printf(_("====>Loading base level theme images.<====\n"));
 
 	/* This loads the base images in the top level of the theme directory.
 	|  For backward compatibility, it also loads monitor specific name
@@ -937,8 +895,6 @@ load_theme_images(void)
 
 	if (gkrellm_using_default_theme())
 		{
-		if (GK.debug_level & DEBUG_IMAGES)
-			printf(_("====>Loading additional default theme images.<====\n"));
 		n_default = sizeof(default_theme_images) / sizeof(ImageTable);
 		load_image_table(&default_theme_images[0], n_default, NULL);
 
@@ -1332,13 +1288,9 @@ parse_config_line(gchar *line, struct _config *cf, gint size)
 			if (pc->minimum > -100 && val < pc->minimum)
 				*(pc->value) = pc->minimum;
 			foundit = TRUE;
-			if (GK.debug_level & DEBUG_GKRELLMRC)
-				printf(_("parse_config %s %s\n"), s, arg);
 			break;
 			}
 		}
-	if ((GK.debug_level & DEBUG_GKRELLMRC) && !foundit)
-		printf(_("parse_config cannot grok %s.\n"), s);
 	}
 
 static void
@@ -1350,12 +1302,7 @@ clear_style_list(GList *list, GList *name_list, gchar *debug_name)
 		{
 		style = (Style *) list->data;
 		if (style)
-			{
-			if (GK.debug_level & DEBUG_STYLES)
-				printf(_("    Clearing style from list: %s %s\n"), debug_name,
-							(gchar *) name_list->data);
 			memset(style, 0, sizeof(Style));
-			}
 		}
 	}
 
@@ -1726,16 +1673,11 @@ parse_gkrellmrc(gint alternative)
 	path = g_strdup_printf("%s/%s%s", GK.theme_path, GKRELLMRC, lbuf);
 	if ((f = fopen(path, "r")) != NULL)
 		{
-		if (GK.debug_level & DEBUG_GKRELLMRC)
-			printf(_("--> Parsing %s\n"), path);
 		while (fgets(buf, sizeof(buf), f))
 			parse_config_line(buf, &theme_config[0],
 					sizeof(theme_config) / sizeof (struct _config));
 		fclose(f);
 		}
-	else if (GK.debug_level & DEBUG_GKRELLMRC)
-		printf(_("--> %s not found\n"), path);
-
 	g_free(path);
 	}
 
@@ -1750,8 +1692,6 @@ gkrellmrc_theme_config(void)
 	{
 	init_theme();
 	load_theme_config();
-	if (GK.debug_level & DEBUG_GKRELLMRC)
-		printf(_("GK.theme_path <%s>\n"), GK.theme_path);
 
 	if (gkrellm_using_default_theme())
 		default_theme_config();
