@@ -22,7 +22,8 @@
 |  4/22/2001  Solaris code contributed by Daisuke Yabuki <dxy@acm.org>
 |  1/23/2001  Hajimu UMEMOTO improvements with read_freebsd_cpu() and
 |               register_freebsd_cpus().
-| 10/12/2000  NetBSD code contributed by Anthony Mallet <metall@ficus.yi.org>
+| 10/12/2000  NetBSD code contributed by Anthony Mallet
+|               <anthony.mallet@useless-ficus.net>
 |  2/25/2000  FreeBSD code contributed by Hajimu UMEMOTO ume@mahoroba.org
 */
 
@@ -298,7 +299,8 @@ register_stat_cpus(void)
 	/* There can be cpu and cpu0 only (single cpu machines with kernel 2.4
 	|  or 2.2 compiled for SMP), and in this case, eliminate cpu0.
 	*/
-	n_smp_cpus = n_cpus - 1;
+	if (n_cpus)
+		n_smp_cpus = n_cpus - 1;
 	if (n_smp_cpus == 1)	/* cpu and cpu0 but no cpu1 (not really SMP)	*/
 		{
 		n_smp_cpus = 0;
@@ -577,10 +579,10 @@ static gint		smp_mode;
 static Monitor	*mon_cpu;
 
 static gboolean	cpu_enabled  = TRUE;
-static gint		omit_nice_mode;
+static gboolean	omit_nice_mode,
+				config_tracking;
 static gint		ascent;
 static gint		style_id;
-static gint		mapped_sensors;
 static gint		sensor_separate_mode;
 
 
@@ -629,7 +631,10 @@ format_chart_text(CpuMon *cpu, gchar *buf, gint size)
 				}
 			if (t >= 0)
 				{
-				t = ((200 * t / cpu->total_diff) + 1) / 2;
+				/* ChartData values have been scaled to the chart max scale
+				|  of CPU_TICKS_PER_SECOND.
+				*/
+				t = ((200 * t / CPU_TICKS_PER_SECOND) + 1) / 2;
 				if (t > 100)
 					t = 100;
 				len = snprintf(buf, size, "%d%%", t);
@@ -650,7 +655,7 @@ draw_cpu_extra(CpuMon *cpu)
 	Chart	*cp  = cpu->chart;
 	gchar	buf[128];
 
-	if (!cp || cpu->total_diff <= 0)
+	if (!cp)
 		return;
 	format_chart_text(cpu, buf, sizeof(buf));
 	gkrellm_draw_chart_text(cp, style_id, buf);
@@ -677,8 +682,8 @@ draw_sensor_decals(CpuMon *cpu)
 	gint	toggle;
 
 	if (   sensor_separate_mode
-		&& (mapped_sensors & SENSOR_TEMPERATURE)
-		&& (mapped_sensors & SENSOR_FAN)
+		&& (cpu->mapped_sensors & SENSOR_TEMPERATURE)
+		&& (cpu->mapped_sensors & SENSOR_FAN)
 	   )
 		{
 		gkrellm_sensor_read_temperature(name, &t, &units);
@@ -689,15 +694,15 @@ draw_sensor_decals(CpuMon *cpu)
 	else
 		{
 		toggle = time_now & 2;
-		if (   (mapped_sensors & SENSOR_FAN)
-			&& (toggle || !(mapped_sensors & SENSOR_TEMPERATURE))
+		if (   (cpu->mapped_sensors & SENSOR_FAN)
+			&& (toggle || !(cpu->mapped_sensors & SENSOR_TEMPERATURE))
 		   )
 			{
 			gkrellm_sensor_read_fan(name, &f);
 			gkrellm_sensor_draw_fan_decal(p, cpu->sensor_decal, f);
 			}
-		else if (   (mapped_sensors & SENSOR_TEMPERATURE)
-				 && (!toggle || !(mapped_sensors & SENSOR_FAN))
+		else if (   (cpu->mapped_sensors & SENSOR_TEMPERATURE)
+				 && (!toggle || !(cpu->mapped_sensors & SENSOR_FAN))
 				)
 			{
 			gkrellm_sensor_read_temperature(name, &t, &units);
@@ -734,8 +739,6 @@ update_cpu(void)
 		total = cpu->user + cpu->nice + cpu->sys + cpu->idle;
 		if (GK.second_tick)
 			{
-			cpu->total_diff = (gint) (total - cpu->previous_total_sec);
-			cpu->previous_total_sec = total;
 			gkrellm_store_chartdata(cp, total, cpu->sys, cpu->user, cpu->nice);
 			refresh_cpu_chart(cpu);
 			}
@@ -814,6 +817,24 @@ cb_cpu_extra(GtkWidget *widget, GdkEventButton *ev)
 	return TRUE;
 	}
 
+static void
+cb_cpu_height(ChartConfig *cf, gpointer data)
+	{
+	GList	*list;
+	Chart	*cp;
+	gint	h;
+
+	if (!config_tracking)
+		return;
+	h = gkrellm_get_chartconfig_height(cf);
+	for (list = cpu_mon_list; list; list = list->next)
+		{
+		cp = ((CpuMon *) list->data)->chart;
+		if (cp->h != h)
+			gkrellm_set_chart_height(cp, h);
+		}
+	}
+
 static void
 setup_cpu_scaling(ChartConfig *cf)
 	{
@@ -925,7 +946,7 @@ adjust_sensors_display(CpuMon *cpu, gint force)
 	|  a temperature.
 	*/
 	p = cpu->chart->panel;
-	mapped_sensors = 0;
+	cpu->mapped_sensors = 0;
 	if (!GK.demo)
 		{
 		gkrellm_mapped_sensor_alert_connect(cpu->name,
@@ -941,11 +962,11 @@ adjust_sensors_display(CpuMon *cpu, gint force)
 	gkrellm_reset_alert(alert);
 
 	if (get_mapped_sensor(cpu->name, SENSOR_TEMPERATURE) || GK.demo)
-		mapped_sensors |= SENSOR_TEMPERATURE;
+		cpu->mapped_sensors |= SENSOR_TEMPERATURE;
 	if (get_mapped_sensor(cpu->name, SENSOR_FAN) || GK.demo)
-		mapped_sensors |= SENSOR_FAN;
+		cpu->mapped_sensors |= SENSOR_FAN;
 
-	if (mapped_sensors & (SENSOR_TEMPERATURE | SENSOR_FAN))
+	if (cpu->mapped_sensors & (SENSOR_TEMPERATURE | SENSOR_FAN))
 		{
 		if (! gkrellm_is_decal_visible(ds) || force)
 			gkrellm_make_decal_visible(p, ds);
@@ -957,8 +978,8 @@ adjust_sensors_display(CpuMon *cpu, gint force)
 			gkrellm_make_decal_invisible(p, ds);
 		position = cpu->save_label_position;
 		}
-	if (   (mapped_sensors & SENSOR_FAN)
-		&& (mapped_sensors & SENSOR_TEMPERATURE)
+	if (   (cpu->mapped_sensors & SENSOR_FAN)
+		&& (cpu->mapped_sensors & SENSOR_TEMPERATURE)
 		&& sensor_separate_mode
 	   )
 		{
@@ -1108,14 +1129,15 @@ create_cpu(GtkWidget *vbox, gint first_create)
 		*/
 		gkrellm_set_chartconfig_auto_grid_resolution(cp->config, FALSE);
 		gkrellm_chartconfig_fixed_grids_connect(cp->config,
-									setup_cpu_scaling, NULL);
+					setup_cpu_scaling, NULL);
+		gkrellm_chartconfig_height_connect(cp->config, cb_cpu_height, NULL);
 		setup_cpu_scaling(cp->config);
 
 		if (! (!strcmp(cpu->name, "cpu") && cpu->is_composite))
 			sensor_create_decals(p, style_id,
 					&cpu->sensor_decal, &cpu->fan_decal);
 
-		sprintf( mapname, _("CPU%c"), (cpu->name)[3] );
+		sprintf( mapname, _("CPU%s"), &(cpu->name)[3] );
 		gkrellm_panel_configure(p, mapname, style);
 		gkrellm_panel_create(cpu->vbox, mon_cpu, p);
 
@@ -1151,7 +1173,8 @@ create_cpu(GtkWidget *vbox, gint first_create)
 static GtkWidget	*cpu_enabled_button,
 					*text_format_combo;
 static GtkWidget	*smp_button[3];
-static GtkWidget	*omit_nice_button;
+static GtkWidget	*omit_nice_button,
+					*equal_h_button;
 static GtkWidget	*sensor_separate_button;
 
 
@@ -1178,6 +1201,7 @@ save_cpu_config(FILE *f)
 	fprintf(f, "%s enable %d\n", CPU_CONFIG_KEYWORD, cpu_enabled);
 	fprintf(f, "%s smp_mode %d\n", CPU_CONFIG_KEYWORD, smp_mode);
 	fprintf(f, "%s omit_nice_mode %d\n", CPU_CONFIG_KEYWORD, omit_nice_mode);
+	fprintf(f, "%s config_tracking %d\n", CPU_CONFIG_KEYWORD, config_tracking);
 	fprintf(f, "%s sensor_mode %d\n", CPU_CONFIG_KEYWORD,
 			sensor_separate_mode);
 	fprintf(f, "%s text_format %s\n", CPU_CONFIG_KEYWORD, text_format);
@@ -1201,6 +1225,8 @@ load_cpu_config(gchar *arg)
 			sscanf(item, "%d\n", &smp_mode);
 		else if (!strcmp(config, "omit_nice_mode"))
 			sscanf(item, "%d\n", &omit_nice_mode);
+		else if (!strcmp(config, "config_tracking"))
+			sscanf(item, "%d\n", &config_tracking);
 		else if (!strcmp(config, "sensor_mode"))
 			sscanf(item, "%d\n", &sensor_separate_mode);
 		else if (!strcmp(config, "text_format"))
@@ -1262,9 +1288,12 @@ apply_cpu_config(void)
 
 	cpu_enabled = GTK_TOGGLE_BUTTON(cpu_enabled_button)->active;
 	if (n_smp_cpus > 0)
+		{
 		for (i = 0; i < 3; ++i)
 			if (GTK_TOGGLE_BUTTON(smp_button[i])->active)
 				smp_mode = i;
+		config_tracking = GTK_TOGGLE_BUTTON(equal_h_button)->active;
+		}
 	omit_nice_mode = GTK_TOGGLE_BUTTON(omit_nice_button)->active;
 	if (sensor_separate_button)
 		sensor_separate_mode =
@@ -1332,6 +1361,9 @@ create_cpu_tab(GtkWidget *tab_vbox)
 		_("Draw fan and temperature values separately (not alternating)."));
 	if (n_smp_cpus > 0)
 		{
+		gkrellm_check_button(vbox, &equal_h_button, config_tracking, FALSE, 0,
+		_("Apply any CPU chart config height change to all CPU charts"));
+
 		vbox1 = gkrellm_framed_vbox(vbox, _("SMP Charts Select"), 4, FALSE,
 				0, 2);
 		hbox = gtk_hbox_new (FALSE, 3);
