@@ -31,12 +31,11 @@ typedef struct
 	gint		enabled;
 	gint		extra_info;
 	gint		is_composite;
-	gint		total_diff;			/* updated per second */
-	gint		previous_total_sec;
-	gulong		previous_total;		/* updated per tick */
+	gulong		previous_total;
 
 	Decal		*sensor_decal,		/* temperature and possibly fan */
 				*fan_decal;			/* fan if separate draw mode	*/
+	gint		mapped_sensors;		/* Which of temp/fan to show	*/
 	gint		save_label_position;  /* When toggling sensors on/off */
 
 	Launcher	launch;
