@@ -19,8 +19,11 @@
 */
 
 /*
+| 10/29/2001  Tomas Ogren <stric@cs.umu.se> Solaris patch avoids adding not
+|               found disks to the disk list.
 |  4/22/2001  Solaris code contributed by Daisuke Yabuki <dxy@acm.org>
-| 10/12/2000  NetBSD code contributed by Anthony Mallet <metall@ficus.yi.org>
+| 10/12/2000  NetBSD code contributed by Anthony Mallet
+|               <anthony.mallet@useless-ficus.net>
 |  2/25/2000  FreeBSD code contributed by Hajimu UMEMOTO ume@mahoroba.org
 */
 
@@ -549,8 +552,9 @@ add_disk_device(gint major, gint minor) {
     if ((disk = lookup_disk_by_device(major, minor)) == NULL) {
         get_devname(major, devname);
         instance = get_instance(minor);
-        if (devname && instance)
-            devid = g_strdup_printf("%s%d", devname, instance);
+        if (!(devname && instance))
+            return NULL;
+        devid = g_strdup_printf("%s%d", devname, instance);
 
         disk = g_new0(DiskMon, 1);
         disk->name = g_strdup(devid);
