@@ -19,8 +19,11 @@
 */
 
 /*
+| 10/29/2001  Darell Tan <dardil@singnet.com.sg> patch adds uid check for
+|               "owner" to fstab_user_permission().
 |  4/22/2001  Solaris code contributed by Daisuke Yabuki <dxy@acm.org>
-| 10/12/2000  NetBSD code contributed by Anthony Mallet <metall@ficus.yi.org>
+| 10/12/2000  NetBSD code contributed by Anthony Mallet
+|               <anthony.mallet@useless-ficus.net>
 |  2/25/2000  FreeBSD code contributed by Hajimu UMEMOTO ume@mahoroba.org
 */
 
@@ -764,7 +767,7 @@ format_fs_data(FSmon *fs, gchar *buf, gint size)
 		buf += len;
 		}
 	*buf = '\0';
-	return u;
+	return u + 1;
 	}
 
   /* Draw the fs label or toggle the fs total blocks and blocks avail.
@@ -830,20 +833,14 @@ eject_cdrom(FSmon *fs)
 		if ((d = open(m->device, (O_RDONLY | O_NONBLOCK))) >= 0)
 #endif
 			{
-			extern int errno;
-
 #if defined(__FreeBSD__)
 			(void) ioctl(d, CDIOCALLOW);
 			n = ioctl(d, CDIOCEJECT);
 #else
 			n = ioctl(d, CDROMEJECT);
 #endif
-			if (GK.debug_level & DEBUG_MISC)
-				printf(_("fs eject %s errno = %d\n"), m->device, errno);
 			close(d);
 			}
-		else if (GK.debug_level & DEBUG_MISC)
-			printf(_("could not open %s\n"), m->device);
 		}
 #endif
 	}
@@ -878,8 +875,6 @@ pipe_command(FSmon *fs, gchar *command)
 	if (fs->launch_mount.pipe)	/* Still running? */
 		return;
 	snprintf(buf, sizeof(buf), "%s 2>&1", command);
-	if (GK.debug_level & DEBUG_MISC)
-		printf(_("pipe mount command: %s\n"), buf);
 	if ((fs->launch_mount.pipe = popen(buf, "r")) == NULL)
 		return;
 	fcntl(fileno(fs->launch_mount.pipe), F_SETFL, O_NONBLOCK);
@@ -1403,7 +1398,12 @@ save_fs_config(FILE *f)
 static gboolean
 fstab_user_permission(Mount *m)
 	{
-	if (strstr(m->options, "user") || strstr(m->options, "owner"))
+	struct stat my_stat;
+	
+	lstat(m->device, &my_stat);
+	if (   strstr(m->options, "user")
+		|| (strstr(m->options, "owner") && my_stat.st_uid == uid)
+	   )
 		return TRUE;
 	return FALSE;
 	}
@@ -1844,7 +1844,7 @@ cb_delete_fs(GtkWidget *widget, gpointer drawer)
 static void
 apply_fs_config(void)
 	{
-	GList			*new_fs_list, *old_fs_list;
+	GList			*list, *new_fs_list, *old_fs_list;
 	FSmon			*fs;
 	gchar			*s;
 	gint			row, need_new_monitor;
@@ -1853,7 +1853,9 @@ apply_fs_config(void)
 	cdrom_auto_eject = GTK_TOGGLE_BUTTON(cdrom_auto_eject_button)->active;
 	binary_units = GTK_TOGGLE_BUTTON(binary_units_button)->active;
 	s = gkrellm_entry_get_text(&(GTK_COMBO(data_format_combo)->entry));
-	gkrellm_dup_string(&data_format, s);
+	if (gkrellm_dup_string(&data_format, s))
+		for (list = fs_mon_list; list; list = list->next)
+			((FSmon *) list->data)->text_decal->value = -1;	/* Force redraw */
 
 	spin = GTK_SPIN_BUTTON(fs_check_spin_button);
 	fs_check_timeout = gtk_spin_button_get_value_as_int(spin);
@@ -2131,7 +2133,7 @@ N_("If a mount point is in your\n"
 "\t/etc/fstab and you have mount permission then mount and umount\n"
 "\tcommands can be enabled and executed for that mount point simply\n"
 "\tby checking the \"Enable /etc/fstab mounting\" option.\n"
-"\tMount table entries in /etc/fstab must have the \"user\" option\n"
+"\tMount table entries in /etc/fstab need the \"user\" or \"owner\" option\n"
 "\tset to grant this permission unless GKrellM is run as root.\n"
 "\tFor example, if you run GKrellM as a normal user and you want\n"
 "\tto be able to mount your floppy, your /etc/fstab could have\n"
@@ -2182,12 +2184,12 @@ N_("\t$l    the panel label\n"),
 "\n",
 N_("<b>Mouse Button Actions:\n"),
 N_("<b>\tLeft "),
-N_("click on a fs monitor label to show/hide secondary fs monitors.\n"),
+N_("click on a panel label to show/hide secondary fs monitors.\n"),
 N_("<b>\tLeft "),
-N_("click on a drive decal to apply mount/umount commands (if enabled)\n"
+N_("click on a panel button to apply mount/umount commands (if enabled)\n"
 	"\t\tto the mount point being monitored.\n"),
 N_("<b>\tMiddle "),
-N_("click on a FS panel to scroll a programmable display\n"),
+N_("click on a panel to scroll a programmable display\n"),
 N_("\t\tof file system capacities (default is total and free space).\n\n"),
 
 N_("At least one primary fs monitor must exist to click on in order to show\n"
