@@ -107,7 +107,7 @@
 */
 #define	GKRELLM_VERSION_MAJOR	1
 #define	GKRELLM_VERSION_MINOR	2
-#define	GKRELLM_VERSION_REV		2
+#define	GKRELLM_VERSION_REV		4
 /* Backward compatibility */
 #define	VERSION_MAJOR			GKRELLM_VERSION_MAJOR
 #define	VERSION_MINOR			GKRELLM_VERSION_MINOR
@@ -929,26 +929,15 @@ struct	ThemeConfig
 	};
 
   /* Debugs for debug_level	*/
-#define	DEBUG_MISC		0x1
-#define	DEBUG_IMAGES	0x2
-#define	DEBUG_GKRELLMRC	0x4
-#define	DEBUG_STYLES	0x8
 #define DEBUG_MAIL		0x10
 #define DEBUG_NET		0x20
 #define DEBUG_TIMER		0x40
-#define	DEBUG_SIZES		0x80
-#define	DEBUG_PLUGIN	0x100
-#define	DEBUG_SENSORS	0x200
-
-/* Internal debugging, not doc'ed in gkrellm --help */
-#define DEBUG_KRELL		0x10000
+#define	DEBUG_SENSORS	0x80
 
 
 extern struct ThemeConfig  GK;
 
 
-
-
 /* ================= User Config ==================*/
 
   /* Values for Monitor id
