@@ -575,7 +575,7 @@ create_about_tab(GtkWidget *vbox)
 #endif
 #if defined(__NetBSD__)
 	buf = g_strdup_printf(_("NetBSD code was contributed by:\n"
-							"Anthony Mallet <metall@ficus.yi.org>"));
+							"Anthony Mallet <anthony.mallet@useless-ficus.net>"));
 	label = gtk_label_new(buf);
 	g_free(buf);
 	gtk_box_pack_start(GTK_BOX(vbox), label, TRUE, TRUE, 0);
@@ -592,9 +592,7 @@ static GtkWidget
 			*update_HZ_spin_button,
 			*width_spin_button;
 
-#if defined(TRACK_GTK_THEMES)
 GtkWidget	*track_gtk_button;
-#endif
 
 static gchar	*info_fonts[3][2] =
 {
@@ -667,9 +665,7 @@ apply_general_config(void)
 	{
 	gint	n;
 
-#if defined(TRACK_GTK_THEMES)
 	GK.track_gtk_rcfiles = GTK_TOGGLE_BUTTON(track_gtk_button)->active;
-#endif
 	GK.enable_hostname = GTK_TOGGLE_BUTTON(enable_hst_button)->active;
 	GK.hostname_short = GTK_TOGGLE_BUTTON(hostname_short_button)->active;
 	GK.enable_system_name = GTK_TOGGLE_BUTTON(enable_sysname_button)->active;
@@ -780,10 +776,8 @@ create_general_tab(GtkWidget *tab_vbox)
 		10,
 		_("Remember screen location at exit and move to it at next startup"));
 
-#if defined(TRACK_GTK_THEMES)
 	gkrellm_check_button(vbox, &track_gtk_button, GK.track_gtk_rcfiles, FALSE,
 		0, _("Track Gtk theme changes for similarly named themes"));
-#endif
 
 	vbox = gkrellm_framed_vbox_end(vbox, NULL, 4, FALSE, 0, 2);
 	gkrellm_spin_button(vbox, &update_HZ_spin_button, (gfloat) GK.update_HZ,
@@ -972,12 +966,7 @@ add_themes_to_list(GList **list, gchar *theme_dir)
 		if (dentry->d_name[0] != '.' && dentry->d_ino > 0)
 			{
 			if (basename_in_list(*list, dentry->d_name))
-				{
-				if (GK.debug_level & DEBUG_MISC)
-					printf("Ignoring duplicate theme %s/%s\n",
-						theme_dir, dentry->d_name);
-				continue;
-				}
+				continue;		/* Duplicate theme */
 			path = g_strdup_printf("%s/%s", theme_dir, dentry->d_name);
 			if (isdir(path, NULL))
 				*list = g_list_append(*list, path);
@@ -1119,9 +1108,6 @@ save_theme_config(void)
 	path = gkrellm_make_config_file_name(gkrellm_homedir(),
 					GKRELLM_THEME_CONFIG);
 
-	if (GK.debug_level & DEBUG_MISC)
-		printf(_("Writting new %s: <%s>\n"), path, GK.theme_path);
-
 	if ((f = fopen(path, "w")) != NULL)
 		{
 		fprintf(f, "%s\n", GK.theme_path);
@@ -1200,13 +1186,11 @@ load_theme_config(void)
 				"-adobe-helvetica-medium-r-*-*-*-100-*-*-*-*-iso8859-*");
 	}
 
-#if defined(TRACK_GTK_THEMES)
   /* Some Gtk themes have a suffix */
 static gchar *gtk_suffix[]	=
 	{
 	"-gtk", "_gtk", "-GTK", "_GTK"
 	};
-#endif
 
   /* Called from cb_client_event.  Triggered by a Gtk theme switch or if
   |  an app sends _GKRELLM_READ_THEME event.
@@ -1219,7 +1203,6 @@ read_theme_event(gint gkrellm_read_theme)
 		g_free(GK.theme_path);
 		GK.theme_path = NULL;	/* Force reread of GKRELLM_THEME_CONFIG */
 		}
-#if defined(TRACK_GTK_THEMES)
 	else if (GK.track_gtk_rcfiles)
 		/* This code currently not accessible (GK.track_gtk_rcfiles is not
 		|  setable) I've heard a master theme switcher (E, Gtk, xmms, gkrellm)
@@ -1269,7 +1252,6 @@ read_theme_event(gint gkrellm_read_theme)
 				}
 			}
 		}
-#endif
 	build_gkrellm();
 	}
 
@@ -1938,30 +1920,6 @@ gkrellm_open_config_window(Monitor *mon)
 	gtk_ctree_select(GTK_CTREE(config_ctree), mon->privat->ctree_config_node);
 	}
 
-static void
-cb_debug(gpointer data, guint action, GtkWidget *widget)
-	{
-	gchar	*new;
-
-	if (GK.debug_level & action)
-		{
-		GK.debug_level &= ~action;
-		new = "OFF";
-		}
-	else
-		{
-		GK.debug_level |= action;
-		new = "ON";
-		}
-	if (action == DEBUG_IMAGES)
-		printf(_("==> Turning _%s_ theme images debugging.\n"), new);
-	if (action == DEBUG_GKRELLMRC)
-		printf(_("==> Turning _%s_ gkrellmrc debugging.\n"), new);
-	if (action == DEBUG_STYLES)
-		printf(_("==> Turning _%s_ style debugging.\n"), new);
-	}
-
-
 static GtkItemFactoryEntry	no_config_items[] =
 	{
 {"/-",				   NULL,	NULL,					0, "<Separator>"},
@@ -1985,10 +1943,7 @@ static GtkItemFactoryEntry	debug_items[] =
 	{"/-",				    NULL,	NULL,					0, "<Separator>"},
 	{N_("/Theme prev"), 	"u",	cb_load_theme,	THEME_PREV,	"<Item>"},
 	{N_("/Theme next"),		"d",	cb_load_theme,	THEME_NEXT,	"<Item>"},
-	{N_("/Reload Theme"),	"F5",	cb_load_theme,	THEME_RELOAD, "<Item>"},
-	{N_("/Debug Images"),	"F6",	cb_debug,	DEBUG_IMAGES, 	"<Item>"},
-	{N_("/Debug gkrellmrc"),"F7",	cb_debug,	DEBUG_GKRELLMRC,"<Item>"},
-	{N_("/Debug styles"),	"F8",	cb_debug,	DEBUG_STYLES,	"<Item>"},
+	{N_("/Reload Theme"),	"F5",	cb_load_theme,	THEME_RELOAD, "<Item>"}
   };
 
 static GtkItemFactory	*debug_factory;
