@@ -23,7 +23,8 @@
 |  1/29/2001  Hajimu UMEMOTO patched better networking code and IPv6 support
 |               into the new TCP connection lookup.  Also improved
 |               read_freebsd_tcp_port_data() with 1/23 patch.
-| 10/12/2000  NetBSD code contributed by Anthony Mallet <metall@ficus.yi.org>
+| 10/12/2000  NetBSD code contributed by Anthony Mallet
+|               <anthony.mallet@useless-ficus.net> 
 |  2/25/2000  FreeBSD code contributed by Hajimu UMEMOTO ume@mahoroba.org
 |               He also added IPv6 support for FreeBSD and Linux.
 */
@@ -865,19 +866,17 @@ draw_inet_mark_data(InetMon *in, gint minute_mark)
 			0, y,  0, y,  cp->w, cp->y);
 	}
 
-static gchar	*weekday_char[]	=
-	{ N_("S"), N_("M"), N_("T"), N_("W"), N_("T"), N_("F"), N_("S") };
-
 static void
 draw_inet_chart(InetMon *in)
 	{
-	struct tm	*tm;
+	struct tm	tm;
 	GdkGC		*gc3;
 	Chart		*cp;
 	TextStyle	*ts;
 	GdkColor	tmp_color;
+	gchar		buf[32];
 	guint32		pixel0, pixel1;
-	gint		y0, h4, h, n, wday, hour, minute;
+	gint		y0, h4, h, n;
 
 	cp = in->chart;
 	gkrellm_draw_chartdata(cp);
@@ -890,19 +889,17 @@ draw_inet_chart(InetMon *in)
 						0, 0, gkrellm_chart_width(), h);
 	ts = gkrellm_chart_alt_textstyle(style_id);
 
-	tm = gkrellm_get_current_time();
+	tm = *gkrellm_get_current_time();
 	gc3 = gkrellm_draw_GC(3);
 	gdk_gc_set_foreground(gkrellm_draw_GC(3), gkrellm_white_color());
 	if (in->hour_mode)
 		{
-		hour = tm->tm_hour;
-		wday = tm->tm_wday;
 		for (n = cp->w - 1; n >= 0; --n)
 			{
 			/* When hour ticked to 0, 23rd hour data was stored and a slot
 			|  was skipped.
 			*/
-			if (hour == 0)	/* Draw day mark at midnight	*/
+			if (tm.tm_hour == 0)	/* Draw day mark at midnight	*/
 				{
 				pixel0 = gdk_image_get_pixel(grid, cp->x + n, 0);
 				tmp_color.pixel = pixel0;
@@ -918,26 +915,29 @@ draw_inet_chart(InetMon *in)
 							cp->x + n, y0 - 3, cp->x + n, 3);
 					}
 				}
-			if (in->extra_info && hour == 1 && n < cp->w - 5)
-				gkrellm_draw_chart_label(in->chart, ts,
-						cp->x + n, in->chart->h - 4, _(weekday_char[wday]));
-			if (--hour < 0)
+			if (in->extra_info && tm.tm_hour == 1 && n < cp->w - 5)
 				{
-				hour = 24;		/* Extra hour for skipped slot	*/
-				if (--wday < 0)
-					wday = 6;
+				strftime(buf, sizeof(buf), "%a", &tm);
+				buf[1] = '\0';
+				gkrellm_draw_chart_label(in->chart, ts,
+						cp->x + n, in->chart->h - 4, buf);
+				}
+			if (--tm.tm_hour < 0)
+				{
+				tm.tm_hour = 24;		/* Extra hour for skipped slot	*/
+				if (--tm.tm_wday < 0)
+					tm.tm_wday = 6;
 				}
 			}
 		}
 	else
 		{
-		minute = tm->tm_min;
 		for (n = cp->w - 1; n >= 0; --n)
 			{
 			/* When minute ticked to 0, 59 minute data was stored and a slot
 			|  was skipped.
 			*/
-			if (minute == 0)	/* Draw hour mark	*/
+			if (tm.tm_min == 0)		/* Draw hour mark	*/
 				{
 				pixel0 = gdk_image_get_pixel(grid, cp->x + n, 0);
 				pixel1 = gdk_image_get_pixel(grid, cp->x + n, 1);
@@ -951,8 +951,8 @@ draw_inet_chart(InetMon *in)
 				gdk_draw_line(cp->pixmap, gc3,
 						cp->x + n, y0 - 3, cp->x + n, y0 - h4);
 				}
-			if (--minute < 0)
-				minute = 60;	/* extra minute for skipped slot */
+			if (--tm.tm_min < 0)
+				tm.tm_min = 60;		/* extra minute for skipped slot */
 			}
 		}
 	if (in->extra_info)
@@ -1257,7 +1257,6 @@ cb_inet_extra(GtkWidget *widget, GdkEventButton *ev)
 		if (ev->button == 1 && ev->type == GDK_BUTTON_PRESS)
 			{
 			in->extra_info = !in->extra_info;
-			in->prev_active0 = -1;	/* XXX Force a redraw */
 			gkrellm_refresh_chart(in->chart);
 			gkrellm_config_modified();
 			}
@@ -1265,7 +1264,7 @@ cb_inet_extra(GtkWidget *widget, GdkEventButton *ev)
 			{
 			in->hour_mode = !in->hour_mode;
 			select_hour_or_minute_chart(in);
-			gkrellm_refresh_chart(in->chart);
+			gkrellm_rescale_chart(in->chart);
 			}
 		else if (   ev->button == 3
 				 || (ev->button == 1 && ev->type == GDK_2BUTTON_PRESS)
@@ -1462,7 +1461,7 @@ create_inet_monitor(GtkWidget *vbox1, InetMon *in, gint first_create)
 	in->mark_data = g_new0(gshort, cp->w);
 
 	if (! first_create)
-		draw_inet_chart(in);
+		gkrellm_rescale_chart(in->chart);
 	}
 
 static void
@@ -1673,9 +1672,6 @@ read_inet_data(Chart *cp, FILE *f, gint minute_chart,
 		n = n * 60 + min;
 		}
 	skew = cur_slot - n;
-	if (GK.debug_level & DEBUG_MISC)
-		printf(_("read_inet_data() %d cur_slot=%d skew=%d\n"), minute_chart,
-					cur_slot, skew);
 
 	gkrellm_reset_chart(cp);
 	for (n = 0; n < width; ++n)
@@ -1806,8 +1802,6 @@ load_inet_data(void)
 			draw_inet_chart(in);
 			continue;
 			}
-		if (GK.debug_level & DEBUG_MISC)
-			printf(_("Loading %s\n"), fname);
 		fgets(buf, sizeof(buf), f);		/* Comment line */
 		fgets(buf, sizeof(buf), f);
 		sscanf(buf, "%d %d %d %d", &min, &hour, &yday, &len);
