@@ -421,8 +421,8 @@ gkrellm_move_krell_yoff(Panel *p, Krell *k, gint y)
 			gdk_draw_pixmap(p->drawing_area->window, GK.draw1_GC,
 					p->bg_pixmap,
 					dr->x_dst, dr->y_dst, dr->x_dst, dr->y_dst, dr->w, dr->h);
-		gkrellm_draw_panel_layers_force(p);
 		}
+	k->modified = TRUE;
 	}
 
 void
@@ -443,22 +443,19 @@ gkrellm_remove_krell(Panel *p, Krell *k)
 	{
 	Draw_rec	*dr;
 
-	if (!p || !k)
+	if (!p || !k || !g_list_find(p->krell, k))
 		return;
-	if (g_list_find(p->krell, k))
+	p->krell = g_list_remove(p->krell, k);
+	dr = &k->draw;
+	if (p->pixmap && p->bg_pixmap)
 		{
-		p->krell = g_list_remove(p->krell, k);
-		dr = &k->draw;
-		if (p->pixmap && p->bg_pixmap)
-			{
-			gdk_draw_pixmap(p->pixmap, GK.draw1_GC, p->bg_pixmap,
+		gdk_draw_pixmap(p->pixmap, GK.draw1_GC, p->bg_pixmap,
+			dr->x_dst, dr->y_dst, dr->x_dst, dr->y_dst, dr->w, dr->h);
+		if (p->drawing_area->window)
+			gdk_draw_pixmap(p->drawing_area->window, GK.draw1_GC,
+				p->bg_pixmap,
 				dr->x_dst, dr->y_dst, dr->x_dst, dr->y_dst, dr->w, dr->h);
-			if (p->drawing_area->window)
-				gdk_draw_pixmap(p->drawing_area->window, GK.draw1_GC,
-					p->bg_pixmap,
-					dr->x_dst, dr->y_dst, dr->x_dst, dr->y_dst, dr->w, dr->h);
-			gkrellm_draw_panel_layers_force(p);
-			}
+		gkrellm_draw_panel_layers_force(p);
 		}
 	}
 
@@ -472,7 +469,7 @@ gkrellm_remove_and_destroy_krell(Panel *p, Krell *k)
 void
 gkrellm_insert_krell(Panel *p, Krell *k, gboolean append)
 	{
-	if (!p || !k)
+	if (!p || !k || g_list_find(p->krell, k))
 		return;
 	if (append)
 		p->krell = g_list_append(p->krell, k);
@@ -663,8 +660,8 @@ gkrellm_move_decal(Panel *p, Decal *d, gint x, gint y)
 		if (p->drawing_area->window)
 			gdk_draw_pixmap(p->drawing_area->window, GK.draw1_GC,
 					p->bg_pixmap, x_old, y_old,  x_old, y_old,   d->w, d->h);
-		gkrellm_draw_panel_layers_force(p);
 		}
+	d->modified = TRUE;
 	}
 
 void
@@ -695,20 +692,17 @@ gkrellm_destroy_decal(Decal *d)
 void
 gkrellm_remove_decal(Panel *p, Decal *d)
 	{
-	if (!p || !d)
+	if (!p || !d || !g_list_find(p->decal, d))
 		return;
-	if (g_list_find(p->decal, d))
+	p->decal = g_list_remove(p->decal, d);
+	if (p->pixmap && p->bg_pixmap)
 		{
-		p->decal = g_list_remove(p->decal, d);
-		if (p->pixmap && p->bg_pixmap)
-			{
-			gdk_draw_pixmap(p->pixmap, GK.draw1_GC, p->bg_pixmap,
-					d->x, d->y,  d->x, d->y,   d->w, d->h);
-			if (p->drawing_area->window)
-				gdk_draw_pixmap(p->drawing_area->window, GK.draw1_GC,
-						p->bg_pixmap, d->x, d->y,  d->x, d->y,   d->w, d->h);
-			gkrellm_draw_panel_layers_force(p);
-			}
+		gdk_draw_pixmap(p->pixmap, GK.draw1_GC, p->bg_pixmap,
+				d->x, d->y,  d->x, d->y,   d->w, d->h);
+		if (p->drawing_area->window)
+			gdk_draw_pixmap(p->drawing_area->window, GK.draw1_GC,
+					p->bg_pixmap, d->x, d->y,  d->x, d->y,   d->w, d->h);
+		gkrellm_draw_panel_layers_force(p);
 		}
 	}
 
@@ -722,7 +716,7 @@ gkrellm_remove_and_destroy_decal(Panel *p, Decal *d)
 void
 gkrellm_insert_decal(Panel *p, Decal *d, gboolean append)
 	{
-	if (!p || !d)
+	if (!p || !d || g_list_find(p->decal, d))
 		return;
 	if (append)
 		p->decal = g_list_append(p->decal, d);
