@@ -19,6 +19,8 @@
 */
 
 /*
+| 10/7/2001 Patch from Andrew Lombardi <andrew@mysticcoders.com>
+|	Added Evolution mail status check to status_is_old().
 | 6/7/2001 Patch from Jason Lunz <j@falooley.org>
 |	Added multimua option.
 | 2/6/2001 Patch from Laurent Caillat-Vallet <caillat@in2p3.fr>
@@ -214,7 +216,8 @@ static gboolean	enable_mail,
 				enable_multimua,		/* allow multiple MUA instances */
 				msg_count_mode,
 				fetch_check_only_mode,
-				reset_remote_mode;
+				reset_remote_mode,
+				unseen_is_new;			/* Accessed but unread */
 
 static gboolean	mh_seq_ignore,
 				checking_mh_mail;
@@ -658,7 +661,9 @@ check_mail_pop3(Mailbox *mbox)
 		|  re-reporting mail is new after MUA button has been clicked.
 		*/
 		if (   sscanf(mbox->tcp_in->str, "+OK %*d %128s", line) == 1
-			&& gkrellm_dup_string((gchar **) (&mbox->private), line)
+			&& (   gkrellm_dup_string((gchar **) (&mbox->private), line)
+				|| unseen_is_new
+			   )
 		   )
 			mbox->new_mail_count = mbox->mail_count;
 
@@ -851,12 +856,14 @@ check_mh_dir(Mailbox *mbox)
   |      new and cur starting with a dot.  Other than this,
   |      readers should not attempt to parse filenames.
   |  So check_maildir() simply looks for files in new and cur.
-  |  See also http://cr.yp.to/proto/maildir.html
+  |  But if unseen_is_new flag is set, look for ":2,*S" file suffix where
+  |  the 'S' indicates the mail is seen.
+  |  See http://cr.yp.to/proto/maildir.html
   */
 static gboolean
 check_maildir(Mailbox *mbox)
 	{
-	gchar			path[256];
+	gchar			path[256], *s;
 	struct dirent	*dentry;
 	DIR 			*dir;
 
@@ -877,8 +884,14 @@ check_maildir(Mailbox *mbox)
 		{
 		while ((dentry = readdir(dir)) != NULL)
 			{
-			if (*dentry->d_name != '.' && dentry->d_ino > 0)
-				mbox->mail_count++;
+			if (*dentry->d_name == '.' || dentry->d_ino == 0)
+				continue;
+			mbox->mail_count++;
+			if (   unseen_is_new
+				&& (s = strchr(dentry->d_name, ':')) != NULL
+				&& !strchr(s, 'S')
+			   )
+				mbox->new_mail_count++;
 			}
 		closedir(dir);
 		}
@@ -901,6 +914,9 @@ check_maildir(Mailbox *mbox)
   |  st_atime > st_mtime is testing if mbox has been read since last new mail.
   |  Mail readers may restore st_mtime after writting status.
   |  And Netscape mail does status with X-Mozilla-Status: xxxx
+  |  
+  |  Evolution uses status with X-Evolution: 00000000-00x0 where x status is
+  |    0: unread   1: read   2: unread + attachments  3: read + attachments
   */
 static gboolean
 status_is_old(gchar *buf)
@@ -910,17 +926,25 @@ status_is_old(gchar *buf)
 
 	/* Standard mail clients
 	*/
-	if (   strncmp(buf, "Status:", 7) == 0
-		&& (strchr(buf, 'R') || strchr(buf, 'O'))	/* R0 0R O */
+	if (   !strncmp(buf, "Status:", 7)
+		&& (strchr(buf, 'R') || (!unseen_is_new && strchr(buf, 'O')))
 	   )
 		return TRUE;
 
 	/* Netscape
 	*/
-	if (   strncmp(buf, "X-Mozilla-Status:", 17) == 0
-		&& strncmp(buf + 18, "0000", 4) != 0
+	if (   !strncmp(buf, "X-Mozilla-Status:", 17)
+		&& strncmp(buf + 18, "0000", 4)
 	   )
 		return TRUE;
+
+	/* Evolution
+	*/
+	if (   !strncmp(buf, "X-Evolution:", 12)
+		&& (!strncmp(buf+24, "1", 1) || !strncmp(buf+24, "3", 1))
+	   )
+		return TRUE;
+
 	return FALSE;
 	}
 
@@ -938,7 +962,9 @@ check_mailbox(Mailbox *mbox)
 
 	if (stat(mbox->path, &s) != 0)
 		{
-		mbox->mail_count = mbox->new_mail_count = 0;
+		mbox->mail_count = mbox->old_mail_count = mbox->new_mail_count = 0;
+		mbox->last_mtime = 0;
+		mbox->last_size = 0;
 		return FALSE;
 		}
 
@@ -964,7 +990,10 @@ check_mailbox(Mailbox *mbox)
 	/* If the mailboxes have been modified since last check, count
 	|  the new/total messages.
 	*/
-	if (s.st_mtime != mbox->last_mtime || s.st_size != mbox->last_size)
+	if (   s.st_mtime != mbox->last_mtime
+		|| s.st_size  != mbox->last_size
+		|| force_mail_check
+	   )
 		{
 		if ((f = fopen(mbox->path, "r")) == NULL)
 			return FALSE;
@@ -1591,7 +1620,6 @@ update_mail(void)
 		local_check |= force_mail_check;
 		if (force_mail_check)
 			minute_count = second_count = 0;
-		force_mail_check = FALSE;
 		any_busy = FALSE;
 
 		for (list = mailbox_list; list; list = list->next)
@@ -1646,6 +1674,8 @@ update_mail(void)
 				mbox->prev_need_animation = mbox->need_animation;
 				}
 			}
+		force_mail_check = FALSE;
+
 		if ((GK.debug_level & DEBUG_MAIL) && (local_check || remote_check))
 			printf(_("**Mail check totals: total=%d new=%d anim=%d\n"),
 				total_mail_count, new_mail_count, run_animation);
@@ -2031,6 +2061,7 @@ save_mail_config(FILE *f)
 	fprintf(f, "mail animation_select_mode %d\n", animation_select_mode);
 	fprintf(f, "mail fetch_check_only_mode %d\n", fetch_check_only_mode);
 	fprintf(f, "mail reset_remote_mode %d\n", reset_remote_mode);
+	fprintf(f, "mail unseen_is_new %d\n", unseen_is_new);
 	fprintf(f, "mail enable %d %d %d %d\n", enable_mail, super_mute_mode,
 						mua_inhibit_mode, enable_multimua);
 	fprintf(f, "mail animation_continuous %d\n", cont_animation_mode);
@@ -2069,6 +2100,8 @@ load_mail_config(gchar *arg)
 			sscanf(item, "%d", &fetch_check_only_mode);
 		else if (strcmp(mail_config, "reset_remote_mode") == 0)
 			sscanf(item, "%d", &reset_remote_mode);
+		else if (strcmp(mail_config, "unseen_is_new") == 0)
+			sscanf(item, "%d", &unseen_is_new);
 		else if (strcmp(mail_config, "enable") == 0)
 			sscanf(item, "%d %d %d %d", &enable_mail, &super_mute_mode,
 						&mua_inhibit_mode, &enable_multimua);
@@ -2106,6 +2139,7 @@ static GtkWidget		*msg_count_button[3];
 static GtkWidget		*animation_select_button[4];
 static GtkWidget		*check_only_button;
 static GtkWidget		*reset_remote_button;
+static GtkWidget		*unseen_is_new_button;
 static GtkWidget		*mua_inhibit_button;
 static GtkWidget		*show_tooltip_button;
 static GtkWidget		*mh_seq_ignore_button;
@@ -2230,6 +2264,10 @@ apply_mail_config(void)
 	mua_inhibit_mode = GTK_TOGGLE_BUTTON(mua_inhibit_button)->active;
 	fetch_check_only_mode = GTK_TOGGLE_BUTTON(check_only_button)->active;
 	reset_remote_mode = GTK_TOGGLE_BUTTON(reset_remote_button)->active;
+	i = GTK_TOGGLE_BUTTON(unseen_is_new_button)->active;
+	if (unseen_is_new != i)
+		force_mail_check = TRUE;
+	unseen_is_new = i;
 	show_tooltip = GTK_TOGGLE_BUTTON(show_tooltip_button)->active;
 	if (mh_seq_ignore_button)
 		mh_seq_ignore = GTK_TOGGLE_BUTTON(mh_seq_ignore_button)->active;
@@ -2599,6 +2637,9 @@ create_mail_tab(GtkWidget *tab_vbox)
     gkrellm_check_button(vbox, &reset_remote_button, reset_remote_mode, TRUE,0,
 		_("Reset remote message counts when message count button is pressed."));
 
+    gkrellm_check_button(vbox, &unseen_is_new_button, unseen_is_new, TRUE, 0,
+	_("Count accessed but unseen mail as new (if this status is available)"));
+
     gkrellm_check_button(vbox, &super_mute_button, super_mute_mode, TRUE, 0,
    _("Mute mode inhibits all mail checking, not just notify (sound) program"));
 
