@@ -133,22 +133,27 @@ static gint		no_transparency;
 static void		apply_rootpixmap_transparency(void);
 static void		apply_frame_transparency(void);
 
-static gchar	*fail_large_font[2] =
+#define	N_FALLBACK_FONTS	3
+
+static gchar	*fail_large_font[N_FALLBACK_FONTS] =
 {
 "-b&h-lucida-bold-r-normal-*-*-120-*-*-*-*-iso8859-*",
-"-adobe-courier-medium-r-*-*-*-120-*-*-*-*-iso8859-*"
+"-adobe-courier-medium-r-*-*-*-120-*-*-*-*-iso8859-*",
+"fixed"
 };
 
-static gchar	*fail_normal_font[2] =
+static gchar	*fail_normal_font[N_FALLBACK_FONTS] =
 {
 "-b&h-lucida-medium-r-normal-*-*-100-*-*-*-*-iso8859-*",
-"-adobe-courier-medium-r-*-*-*-100-*-*-*-*-iso8859-*"
+"-adobe-courier-medium-r-*-*-*-100-*-*-*-*-iso8859-*",
+"fixed"
 };
 
-static gchar	*fail_small_font[2] =
+static gchar	*fail_small_font[N_FALLBACK_FONTS] =
 {
 "-adobe-helvetica-medium-r-normal-*-*-80-*-*-*-*-iso8859-*",
-"-adobe-courier-medium-r-*-*-*-80-*-*-*-*-iso8859-*"
+"-adobe-courier-medium-r-*-*-*-80-*-*-*-*-iso8859-*",
+"fixed"
 };
 
 
@@ -167,10 +172,7 @@ setup_fonts()
 
 	if ((font = (*font_load_func)(GK.large_font_string)) == NULL)
 		{
-		if (GK.debug_level & DEBUG_GKRELLMRC)
-			printf(_("Could not load large font\n  \"%s\"\nFalling back...\n"),
-						GK.large_font_string);
-		for (i = 0; i < 2; ++i)
+		for (i = 0; i < N_FALLBACK_FONTS; ++i)
 			if ((font = (*font_load_func)(fail_large_font[i])) != NULL)
 				break;
 		}
@@ -180,10 +182,7 @@ setup_fonts()
 
 	if ((font = (*font_load_func)(GK.normal_font_string)) == NULL)
 		{
-		if (GK.debug_level & DEBUG_GKRELLMRC)
-			printf(_("Could not load label font\n  \"%s\"\nFalling back...\n"),
-						GK.normal_font_string);
-		for (i = 0; i < 2; ++i)
+		for (i = 0; i < N_FALLBACK_FONTS; ++i)
 			if ((font = (*font_load_func)(fail_normal_font[i])) != NULL)
 				break;
 		}
@@ -193,10 +192,7 @@ setup_fonts()
 
 	if ((font = (*font_load_func)(GK.small_font_string)) == NULL)
 		{
-		if (GK.debug_level & DEBUG_GKRELLMRC)
-			printf(_("Could not load alt font\n  \"%s\"\nFalling back...\n"),
-							GK.small_font_string);
-		for (i = 0; i < 2; ++i)
+		for (i = 0; i < N_FALLBACK_FONTS; ++i)
 			if ((font = (*font_load_func)(fail_small_font[i])) != NULL)
 				break;
 		}
@@ -383,7 +379,7 @@ set_or_save_position(gint save)
 			}
 		save_position_countdown = 0;
 		}
-	else
+	else if (!withdrawn)  /* Putting in slit conflicts with setting position */
 		{
 		if ((f = fopen(path, "r")) != NULL)
 			{
@@ -675,13 +671,7 @@ apply_rootpixmap_transparency()
 		XFree(prop_return);
 		}
 	if (root_xpixmap == None)
-		{
-		if (GK.debug_level & DEBUG_MISC)
-			printf("Cannot get root pixmap [%lx,%d,%ld,%ld,%d]\n",
-				(gulong) ret_type, fmt, nitems, bytes_after,
-				(gint) sizeof(Pixmap));
 		return;
-		}
 	if (trans_gc == NULL)
 		{
 		trans_gc = gdk_gc_new(top_window->window);
@@ -695,9 +685,6 @@ apply_rootpixmap_transparency()
 		|| depth_ret != depth_visual
 	   )
 		{
-		if (GK.debug_level & DEBUG_MISC)
-			printf("Mismatch: root depth = %d visual depth = %d\n",
-					depth_ret, depth_visual);
 		root_xpixmap = None;
 		return;
 		}
@@ -797,18 +784,20 @@ top_frame_button_press(GtkWidget *widget, GdkEventButton *ev, gpointer data)
 		}
 	gdk_window_raise(top_window->window);
 
-	/* I need pointer coords relative to top_window.  So, add in offsets
-	|  to hostname window if that is where we pressed.
-	*/
-	x_press_event = ev->x;
-	y_press_event = ev->y;
-	if (widget == gtree.top1_event_box)
+	if (!withdrawn)		/* Move window unless in the slit */
 		{
-		x_press_event += GK.frame_left_width;
-		y_press_event += GK.frame_top_height;
-		}
-	if (!withdrawn)	/* Needed according to Wes Hopkins <weshopkins@home.com> */
+		/* I need pointer coords relative to top_window.  So, add in offsets
+		|  to hostname window if that is where we pressed.
+		*/
+		x_press_event = ev->x;
+		y_press_event = ev->y;
+		if (widget == gtree.top1_event_box)
+			{
+			x_press_event += GK.frame_left_width;
+			y_press_event += GK.frame_top_height;
+			}
 		moving_gkrellm = TRUE;
+		}
 	}
 
 #define	CLOSE_LEFT	0
@@ -838,15 +827,9 @@ apply_frame_transparency()
 		gtree.window_transparency_mask = gdk_pixmap_new(win->window, w, h, 1);
 		w_prev = w;
 		h_prev = h;
-		if (GK.debug_level & DEBUG_SIZES)
-			printf(_("(new mask allocated) "));
 		}
 	else if (monitors_visible == mask_monitors_visible)
-		{
-		if (GK.debug_level & DEBUG_SIZES)
-			printf(_("(re-using previous mask)\n"));
 		return;
-		}
 
 	/* Set entire shape mask to 1, then write in the frame masks.
 	*/
@@ -892,10 +875,6 @@ apply_frame_transparency()
 
 	gdk_window_shape_combine_mask(gtree.window->window,
 				gtree.window_transparency_mask, 0, 0);
-	if (GK.debug_level & DEBUG_SIZES)
-		printf(_("Transparency mask w=%d h=%d tf_h=%d bf_h=%d sf_h=%d\n"),
-			w, h, GK.frame_top_height, GK.frame_bottom_height,
-			GK.monitor_height);
 	mask_monitors_visible = monitors_visible;
 	}
 
@@ -911,7 +890,7 @@ side_frame_button_press(GtkWidget *widget, GdkEventButton *ev, gpointer data)
 					ev->button, ev->time);
 		return;
 		}
-	if (window_decorations)
+	if (window_decorations || withdrawn)
 		return;
 	gdk_window_get_origin(gtree.window->window, &x_gkrell, &y_gkrell);
 	direction = (x_gkrell < w_display / 2) ? CLOSE_LEFT : CLOSE_RIGHT;
@@ -1009,11 +988,6 @@ create_frame_top(GtkWidget *vbox)
 	gtk_box_pack_start(GTK_BOX(ft_vbox), ft_pixmapwid,
 				/* expand */ FALSE, /* fill */ FALSE, /* padding */ 0);
 	gtk_widget_show (ft_pixmapwid);
-
-	if (GK.debug_level & DEBUG_SIZES)
-		printf(_("frame_top: w=%d im_height=%d h=%d T=%d\n"),
-				w, im->rgb_height, h, gtree.frame_top_mask ? 1 : 0);
-
 	}
 
 static void
@@ -1047,11 +1021,6 @@ create_frame_bottom(GtkWidget *vbox)
 	gtk_box_pack_start(GTK_BOX(fb_vbox), fb_pixmapwid,
 				/* expand */ FALSE, /* fill */ FALSE, /* padding */ 0);
 	gtk_widget_show (fb_pixmapwid);
-
-	if (GK.debug_level & DEBUG_SIZES)
-		printf(_("frame_bottom: w=%d im_height=%d h=%d T=%d\n"),
-				w, im->rgb_height, h, gtree.frame_top_mask ? 1 : 0);
-
 	}
 
 
@@ -1119,11 +1088,6 @@ gkrellm_pack_side_frames(void)
 		GK.frame_right_width = 0;
 		return;
 		}
-	if (GK.debug_level & DEBUG_SIZES)
-		printf(_("pack_side_frames mon_width=%d mon_height=%d "),
-				GK.chart_width + GK.frame_left_width + GK.frame_right_width,
-				GK.monitor_height + total_frame_height);
-
 	gdk_window_get_origin(gtree.window->window, &x_gkrell, &y_gkrell);
 	gdk_window_get_size(gtree.window->window, &w, &h);
 	was_on_bottom = (y_gkrell + h >= h_display) ? TRUE : FALSE;
@@ -1152,9 +1116,6 @@ gkrellm_pack_side_frames(void)
 	*/
 	h = GK.monitor_height + total_frame_height;
 	y_bottom = h_display - (y_gkrell + h);
-	if (GK.debug_level & DEBUG_SIZES)
-		printf(_("y_bottom=%d h_display=%d y_gkrell=%d\n"),
-				y_bottom, h_display, y_gkrell);
 	if (y_bottom < 0)
 		{
 		if ((y = y_gkrell + y_bottom) < 0)
@@ -1443,8 +1404,6 @@ cb_configure_notify(GtkWidget *widget, GdkEventConfigure *ev, gpointer data)
 		&& (w_gkrellm != w || h_gkrellm != h)
 	   )
 		{
-		if (GK.debug_level & DEBUG_SIZES)
-			printf(_("Overriding user window resize!\n"));
 		gdk_window_resize(top_window->window, w_gkrellm, h_gkrellm);
 		w = w_gkrellm;
 		h = h_gkrellm;
@@ -1453,12 +1412,8 @@ cb_configure_notify(GtkWidget *widget, GdkEventConfigure *ev, gpointer data)
 	position_change = (x != x_prev) | (y != y_prev);
 
 	if (size_change)
-		{
-		if (GK.debug_level & DEBUG_SIZES)
-			printf(_("****config_notify w=%d h=%d gk_width=%d gk_height=%d\n"),
-				w, h, w_gkrellm, h_gkrellm);
 		apply_frame_transparency();
-		}
+
 	/* This is abit of a hose... I have to defer applying the root pixmap
 	|  because windows just appearing by gtk_widget_show() are not in the
 	|  right place yet even though configure notify is sent.
@@ -1589,16 +1544,10 @@ N_("usage: gkrellm [options]\n"
 "   -d, --debug-level n      Turn debugging on for selective code sections.\n"
 
 "\ndebug-level numbers are (bitwise OR to debug multiple sections):\n"
-"     0x1   misc\n"
-"     0x2   images\n"
-"     0x4   gkrellmrc\n"
-"     0x8   styles\n"
 "     0x10  mail\n"
 "     0x20  net\n"
 "     0x40  timer button\n"
-"     0x80  size changes\n"
-"     0x100 plugins\n"
-"     0x200 sensors\n\n"
+"     0x80  sensors\n\n"
 );
 
 static void
@@ -1806,6 +1755,7 @@ quit_gkrellm(gint sig)
 static void
 setup_signal_handler(void)
 	{
+	signal(SIGPIPE, SIG_IGN);
 	signal(SIGINT, quit_gkrellm);
 	signal(SIGQUIT, quit_gkrellm);
 	signal(SIGTERM, quit_gkrellm);
@@ -1990,7 +1940,9 @@ main (int argc, char *argv[])
 	create_widget_tree();
 	top_window = gtree.window;
 	
-
+	if (GK.debug_level)
+		printf("GKrellM %d.%d.%d\n", GKRELLM_VERSION_MAJOR,
+				GKRELLM_VERSION_MINOR, GKRELLM_VERSION_REV);
 	check_gkrellm_directories();
 	load_builtin_monitors();
 	load_plugin_monitors();
