@@ -22,7 +22,8 @@
 |  4/22/2001  Solaris code contributed by Daisuke Yabuki <dxy@acm.org>
 |  1/23/2001  Hajimu UMEMOTO added get_bufspace(), improved
 |               read_freebsd_meminfo().
-| 10/12/2000  NetBSD code contributed by Anthony Mallet <metall@ficus.yi.org>
+| 10/12/2000  NetBSD code contributed by Anthony Mallet
+|		<anthony.mallet@useless-ficus.net>
 |  5/27/2000  Patch from William Carrel <william.a@carrel.org> and 
 |               Hajimu UMEMOTO ume@mahoroba.org to cleanup FreeBSD swap code.
 |  2/25/2000  FreeBSD code contributed by Hajimu UMEMOTO ume@mahoroba.org
@@ -50,6 +51,12 @@
   |      set_integer mem_krell_cache_x_hot n
   */
 
+#if defined(G_HAVE_GINT64)
+typedef guint64	memint;
+#else
+typedef gulong	memint;
+#endif
+
 typedef struct
 	{
 	Panel		*panel;
@@ -71,7 +78,7 @@ typedef struct
 
 	/* (*(read_system_meminfo))() fills in this data
 	*/
-	gulong	total,		/* Total memory or swap in system */
+	memint	total,		/* Total memory or swap in system */
 			used,		/* Amount of memory (calulated) or swap used  */
 			x_used,		/* Raw kernel value, not used by swap monitor */
 			free,		/* Not used by swap	monitor */
@@ -151,9 +158,9 @@ extern	kvm_t	*kvmd;
 extern	char	errbuf[];
 
 static int
-swapmode(long *retavail, long *retfree)
+swapmode(memint *retavail, memint *retfree)
 	{
-	int used, avail;
+	memint used, avail;
 #if  __FreeBSD_version >= 400000
 	static int psize = -1;
 	struct kvm_swap kvmswap;
@@ -332,7 +339,7 @@ swapmode(long *retavail, long *retfree)
 	}
 
 static int
-get_bufspace(unsigned long *bufspacep)
+get_bufspace(memint *bufspacep)
 	{
 #if  __FreeBSD_version < 300000
 	u_int	bufspace;
@@ -548,14 +555,24 @@ read_proc_meminfo(void)
 			while ((fgets(buf, sizeof(buf), f)) != NULL)
 				{
 				if (strncmp(buf, "Mem:", 4) == 0)
+#if defined(G_HAVE_GINT64)
+					sscanf(buf,"Mem: %Lu %Lu %Lu %Lu %Lu %Lu",
+						&mem.total, &mem.x_used, &mem.free,
+						&mem.shared, &mem.buffers, &mem.cached);
+#else
 					sscanf(buf,"Mem: %lu %lu %lu %lu %lu %lu",
 						&mem.total, &mem.x_used, &mem.free,
 						&mem.shared, &mem.buffers, &mem.cached);
-
+#endif
 				if (strncmp(buf, "Swap:", 5) == 0)
 					{
+#if defined(G_HAVE_GINT64)
+					sscanf(buf,"Swap: %Lu %Lu", &swap.total,
+						&swap.used);
+#else
 					sscanf(buf,"Swap: %lu %lu", &swap.total,
 						&swap.used);
+#endif
 					break;
 					}
 				}
@@ -727,12 +744,12 @@ read_glibtop_meminfo(void)
 		return;
 
 	glibtop_get_mem (&glt_mem);
-	mem.total   = (gulong) glt_mem.total;
-	mem.x_used    = (gulong) glt_mem.used;
-	mem.free    = (gulong) glt_mem.free;
-	mem.shared  = (gulong) glt_mem.shared;
-	mem.buffers = (gulong) glt_mem.buffer;
-	mem.cached  = (gulong) glt_mem.cached;
+	mem.total   = (memint) glt_mem.total;
+	mem.x_used    = (memint) glt_mem.used;
+	mem.free    = (memint) glt_mem.free;
+	mem.shared  = (memint) glt_mem.shared;
+	mem.buffers = (memint) glt_mem.buffer;
+	mem.cached  = (memint) glt_mem.cached;
 
 	/* Not sure why, but glibtop has a used memory calculation:
 	|  glt_mem.used = mem.total - mem.free - mem.shared
@@ -742,8 +759,8 @@ read_glibtop_meminfo(void)
 	mem.used = mem.x_used - mem.buffers - mem.cached;
 
 	glibtop_get_swap (&glt_swap);
-	swap.total = (gulong) glt_swap.total;
-	swap.used  = (gulong) glt_swap.used;
+	swap.total = (memint) glt_swap.total;
+	swap.used  = (memint) glt_swap.used;
 	if (glt_swap.flags
 				& ((1 << GLIBTOP_SWAP_PAGEIN) + (1 << GLIBTOP_SWAP_PAGEOUT)))
 		{
@@ -797,7 +814,7 @@ static gint			x_scroll,
 
 static MeminfoMeter		*mon_in_motion;
 
-#define MEG(x)	(((x) + (1 << 19)) >> 20)
+#define MEG(x)	((gulong)(((x) + (1 << 19)) >> 20))
 
 
   /* Updating the /proc/meminfo meters can be expensive in Linux 2.2,
@@ -901,7 +918,7 @@ format_meminfo_data(MeminfoMeter *mm, gchar *buf, gint size)
 		buf += len;
 		}
 	*buf = '\0';
-	return u;		/* A way to know if decal text changed. */
+	return u + 1;		/* A way to know if decal text changed. */
 	}
 
 static gint
@@ -1086,9 +1103,9 @@ update_meminfo(void)
 		mem.krell_used->full_scale = (gint) (mem.total >> 12);
 		mem.krell_buffers->full_scale = mem.krell_used->full_scale;
 		mem.krell_cache->full_scale = mem.krell_used->full_scale;
-		u = mem.used >> 12;
-		b = u + (mem.buffers >> 12);
-		c = b + (mem.cached >> 12);
+		u = (gulong) (mem.used >> 12);
+		b = u + (gulong)(mem.buffers >> 12);
+		c = b + (gulong)(mem.cached >> 12);
 		if (   (mem.label_is_data && mon_in_motion && x_moved)
 			|| mem.mouse_entered
 		   )
@@ -1101,7 +1118,7 @@ update_meminfo(void)
 	if (swap.enabled)
 		{
 		swap.krell_used->full_scale = (gint) (swap.total >> 12);
-		u = swap.used >> 12;
+		u = (gulong)(swap.used >> 12);
 		if (   (swap.label_is_data && mon_in_motion && x_moved)
 			|| swap.mouse_entered
 		   )
@@ -1588,9 +1605,11 @@ apply_meminfo_config(void)
 	gint	new_enabled;
 
 	s = gkrellm_entry_get_text(&(GTK_COMBO(mem_format_combo)->entry));
-	gkrellm_dup_string(&mem.data_format, s);
+	if (gkrellm_dup_string(&mem.data_format, s))
+		mem.decal_label->value = -1;	/* Force redraw */
 	s = gkrellm_entry_get_text(&(GTK_COMBO(swap_format_combo)->entry));
-	gkrellm_dup_string(&swap.data_format, s);
+	if (gkrellm_dup_string(&swap.data_format, s))
+		swap.decal_label->value = -1;
 
 	s = gkrellm_entry_get_text(&(GTK_COMBO(text_format_combo)->entry));
 	gkrellm_dup_string(&text_format, s);
