@@ -22,7 +22,8 @@
 |  4/22/2001  Solaris code contributed by Daisuke Yabuki <dxy@acm.org>
 |  1/23/2001  Hajimu UMEMOTO merged Free/Net/Open BSD code into one
 |               read_bsd_net_data().
-| 10/12/2000  NetBSD code contributed by Anthony Mallet <metall@ficus.yi.org>
+| 10/12/2000  NetBSD code contributed by Anthony Mallet
+|		<anthony.mallet@useless-ficus.net> 
 |  7/30/2000  Patch from Yuuki NINOMIYA <gm@debian.or.jp>
 |               Added seconds to the timer button online time.
 |  2/25/2000  FreeBSD code contributed by Hajimu UMEMOTO <ume@mahoroba.org>
@@ -399,7 +400,7 @@ sync_linux_net_interfaces(void)
 		while (fgets(buf, sizeof(buf), f))
 			{
 			if (   ((s = strtok(buf, " \t\n")) == NULL)
-				|| strncmp(s, "lo", 2) == 0
+//				|| strncmp(s, "lo", 2) == 0
 				|| strncmp(s, "dummy", 5) == 0
 				|| (*s == '*' && *(s+1) == '\0')
 			   )
@@ -2229,8 +2230,8 @@ N_("<b>Chart Labels\n"),
 N_("Substitution variables for the format string for chart labels:\n"),
 N_("\t$M    maximum chart value\n"),
 N_("\t$T    total receive + transmit bytes\n"),
-N_("\t$t    receive bytes\n"),
-N_("\t$r    transmit bytes\n"),
+N_("\t$r    receive bytes\n"),
+N_("\t$t    transmit bytes\n"),
 N_("\t$L    the optional chart label\n")
 }
 ;
