@@ -524,7 +524,7 @@ static GList		*plugins_list,
 static gboolean		plugin_enable_list_modified,
 					plugin_placement_modified;
 
-gchar				*plugin_install_log = "";
+gchar				*plugin_install_log;
 
 
 Monitor *
@@ -580,7 +580,7 @@ static void
 plugin_log(gchar *string1, ...)
 	{
 	va_list	args;
-	gchar	*s;
+	gchar	*s, *old_log;
 
 	if (!string1)
 		return;
@@ -588,9 +588,12 @@ plugin_log(gchar *string1, ...)
 	s = string1;
 	while (s)
 		{
-		plugin_install_log = g_strconcat(plugin_install_log, s, NULL);
-		if (GK.debug_level & DEBUG_PLUGIN)
-			printf("%s", s);
+		old_log = plugin_install_log;
+		if (plugin_install_log)
+			plugin_install_log = g_strconcat(plugin_install_log, s, NULL);
+		else
+			plugin_install_log = g_strconcat(s, NULL);
+		g_free(old_log);
 		s = va_arg(args, gchar *);
 		}
 	va_end(args);
