@@ -28,7 +28,10 @@
 |       unified config for sensor interface and voltage monitor
 */
 
-/* 2/25/2000  FreeBSD code contributed by Hajimu UMEMOTO ume@mahoroba.org
+/*
+|  10/29/2001  NetBSD code contributed by
+|                Anthony Mallet anthony.mallet@useless-ficus.net
+|   2/25/2000  FreeBSD code contributed by Hajimu UMEMOTO ume@mahoroba.org
 */
 
 #include "gkrellm.h"
@@ -36,13 +39,36 @@
 
 #include <dirent.h>
 
+  /* chips in a class use a common VoltDefault struct */
+typedef enum
+	{
+	lm78,		/* includes lm78 lm79 w83781d sis5595 */
+	w83xxx,		/* includes w83782d w83783s w83627hf */
+	lm80,
+	gl518,
+	gl520,
+	via686,
+	adm1025,
+	mtp008,
+	it87
+	}
+	ChipClass;
 
 typedef struct
+	{
+	gchar	*name;
+	gfloat	factor;
+	gfloat	offset;
+	gchar	*vref;
+	}
+	VoltDefault;
+
+typedef struct _sensor
 	{
 	gchar		*name;			/* cpuX, mb, Vx name mapped to this sensor */
 	gchar		*path;			/* Pathname to sensor data or device file */
 	gint		type;
-#if defined(__FreeBSD__)
+#if defined(__FreeBSD__) || defined(__NetBSD__)
 	gint		iodev;
 	gint		interface;
 #endif
@@ -50,14 +76,25 @@ typedef struct
 	gint		enabled;		/* voltage enable */
 	gfloat		factor;			/* Scale sensor reading		*/
 	gfloat		offset;			/* Add to sensor reading	*/
+	struct _sensor
+				*vref;			/* A neg volt may be function of a ref volt */
+
+	ChipClass	chip_class;
+	VoltDefault	*voltdefault;
+	gint		voltdefaultsize;
+	gint		volt_order;
+	gboolean	has_config;
 
 	GtkWidget	*select_button;	/* Voltages tab */
 	GtkWidget	*entry;
 	GtkWidget	*factor_spin_button;
 	GtkWidget	*offset_spin_button;
+	GtkWidget	*volt_order_spin_button;
 	GtkWidget	*alert_button;
+	GtkWidget	*vref_entry;
 
 	gfloat		value;
+	gboolean	value_valid;
 
 	Alert		*alert;
 	void		(*cb_alert)();
@@ -68,35 +105,122 @@ typedef struct
 
 static GList	*sensor_list	= NULL;
 
+static gint		n_volt_sensors;
+static gboolean	need_vref_config;
+
 static gboolean	(*get_temperature)(Sensor *);
 static gboolean	(*get_fan)(Sensor *);
 static gboolean	(*get_voltage)(Sensor *);
 
-static struct _voltage_map
+
+  /* Tables of voltage correction factors and offsets derived from the
+  |  compute lines in sensors.conf.  See the README file.
+  */
+	/* "lm78-*" "lm78-j-*" "lm79-*" "w83781d-*" "sis5595-*" "as99127f-*" */
+	/* Values from LM78/LM79 data sheets	*/
+static VoltDefault	voltdefault0[] =
 	{
-	gchar	*name;
-	gfloat	factor;
-	}
-	voltage_map[] =			/* --- Factors from sensors.conf.eg --- */
-	{						/*lm78/79	Winbond		w83xxx (offset)	*/
-	{ "Vcor1",	1.0 },
-	{ "Vcor2",	1.0 },
-	{ "+3.3V",	1.0 },
-#if defined(__FreeBSD__)
-	{ "+5V",	1.67 },		/* 1.68		1.68		1.68				*/
-	{ "+12V",	4.0 },		/*	4.0		3.8			3.8					*/
-	{ "-12V",	4.0 },		/* -4.0		-3.48		5.14 (offset -14.91) */
-	{ "-5V",	1.67 },		/* -1.67	-1.51		3.14 (offset -7.71)	*/
-#else
-	{ "+5V",	1.68 },		/* 1.68		1.68		1.68				*/
-	{ "+12V",	3.9 },		/*	4.0		3.8			3.8					*/
-	{ "-12V",	1.0 },		/* -4.0		-3.48		5.14 (offset -14.91) */
-	{ "-5V",	1.0 },		/* -1.67	-1.51		3.14 (offset -7.71)	*/
-#endif
-	{ "V5SB",	1.0 },
-	{ "VBat",	1.0 }
+	{ "Vcor1",	1.0,    0, NULL },
+	{ "Vcor2",	1.0,    0, NULL },
+	{ "+3.3V",	1.0,    0, NULL },
+	{ "+5V",	1.68,   0, NULL },		/* in3 ((6.8/10)+1)*@	*/
+	{ "+12V",	4.0,    0, NULL },		/* in4 ((30/10)+1)*@	*/
+	{ "-12V",	-4.0,   0, NULL },		/* in5 -(240/60)*@		*/
+	{ "-5V",	-1.667, 0, NULL }		/* in6 -(100/60)*@		*/
 	};
 
+#if defined(__linux__)
+	/* "w83782d-*" "w83783s-*" "w83627hf-*" */
+static VoltDefault	voltdefault1[] =
+	{
+	{ "Vcor1",	1.0,   0, NULL },
+	{ "Vcor2",	1.0,   0, NULL },
+	{ "+3.3V",	1.0,   0, NULL },
+	{ "+5V",	1.68,  0, NULL },		/* in3 ((6.8/10)+1)*@		*/
+	{ "+12V",	3.80,  0, NULL },		/* in4 ((28/10)+1)*@		*/
+	{ "-12V",	5.14 , -14.91, NULL },	/* in5 (5.14 * @) - 14.91	*/
+	{ "-5V",	3.14 , -7.71,  NULL },	/* in6 (3.14 * @) -  7.71	*/
+	{ "V5SB",	1.68,  0, NULL },		/* in7 ((6.8/10)+1)*@		*/
+	{ "VBat",	1.0,   0, NULL }
+	};
+
+	/* lm80-*	*/
+static VoltDefault	voltdefault2[] =
+	{
+	{ "+5V",	2.633, 0, NULL },		/* in0 (24/14.7 + 1) * @	*/
+	{ "VTT",	1.0,   0, NULL },
+	{ "+3.3V",	1.737, 0, NULL },		/* in2 (22.1/30 + 1) * @	*/
+	{ "Vcore",	1.474, 0, NULL },		/* in3 (2.8/1.9) * @		*/
+	{ "+12V",	6.316, 0, NULL },		/* in4 (160/30.1 + 1) * @	*/
+	{ "-12V",	5.482, -4.482, "in0" },	/* in5 (160/35.7)*(@ - in0) + @	*/
+	{ "-5V",	3.222, -2.222, "in0" }	/* in6 (36/16.2)*(@ - in0) + @	*/
+	};
+
+	/* gl518sm-*	*/
+static VoltDefault	voltdefault3[] =
+	{
+	{ "+5V",	1.0,   0, NULL },		/* vdd */
+	{ "+3.3V",	1.0,   0, NULL },		/* vin1 */
+	{ "+12V",	4.192, 0, NULL },		/* vin2 (197/47)*@	*/
+	{ "Vcore",	1.0,   0, NULL }		/* vin3 */
+	};
+
+	/* gl520sm-*	*/
+static VoltDefault	voltdefault4[] =
+	{
+	{ "+5V",	1.0,   0,    NULL },	/* vdd */
+	{ "+3.3V",	1.0,   0,    NULL },	/* vin1 */
+	{ "+12V",	4.192, 0,    NULL },	/* vin2 (197/47)*@	*/
+	{ "Vcore",	1.0,   0,    NULL },	/* vin3 */
+	{ "-12V",	5.0,   -4.0, "vdd" }	/* vin4 (5*@)-(4*vdd)	*/
+	};
+
+	/* via686a-*	*/
+static VoltDefault	voltdefault5[] =
+	{
+	{ "Vcor",	1.02,  0, NULL },		/* in0 */
+	{ "+2.5V",	1.0,   0, NULL },		/* in1 */
+	{ "I/O",	1.02,  0, NULL },		/* in2 */
+	{ "+5V",	1.009, 0, NULL },		/* in3 */
+	{ "+12V",	1.04,  0, NULL }		/* in4 */
+	};
+
+	/* mtp008-*	*/
+static VoltDefault	voltdefault6[] =
+	{
+	{ "Vcor1",	1.0,   0,       NULL },		/* in0 */
+	{ "+3.3V",	1.0,   0,       NULL },		/* in1 */
+	{ "+12V",	3.8,   0,       NULL },		/* in2 @ * 38 / 10*/
+	{ "Vcor2",	1.0,   0,       NULL },		/* in3 */
+	{ "?",		1.0,   0,       NULL },		/* in4 */
+	{ "-12V",	5.143, -16.944, NULL },		/* in5 (@ * 36 - 118.61) / 7*/
+	{ "Vtt",	1.0,   0,       NULL }		/* in6 */
+	};
+
+	/* adm1025-*	*/
+static VoltDefault	voltdefault7[] =
+	{
+	{ "+2.5V",	1.0,   0,       NULL },		/* in0 */
+	{ "VCCP",	1.0,   0,       NULL },		/* in1 */
+	{ "+3.3V",	1.0,   0,       NULL },		/* in2 */
+	{ "+5V",	1.0,   0,       NULL },		/* in3 */
+	{ "+12V",	1.0,   0,       NULL },		/* in4 */
+	{ "VCC",	1.0,   0,       NULL }		/* in5 */
+	};
+
+	/* it878-*	*/
+static VoltDefault	voltdefault8[] =
+	{
+	{ "Vcor1",	1.0,    0, NULL },
+	{ "Vcor2",	1.0,    0, NULL },
+	{ "+3.3V",	2.0,    0, NULL },		/* in2 (1 + 1)*@		*/
+	{ "+5V",	1.68,   0, NULL },		/* in3 ((6.8/10)+1)*@	*/
+	{ "+12V",	4.0,    0, NULL },		/* in4 ((30/10)+1)*@	*/
+	{ "-12V",	-7.2,   0, NULL },		/* in5 -(72/10)*@		*/
+	{ "-5V",	-5.6,   0, NULL },		/* in6 -(56/10)*@		*/
+	{ "Stby",	1.68,   0, NULL }		/* in7 ((6.8/10)+1)*@	*/
+	};
+#endif	/* __linux__ */
 
 /* ====== System dependent interface ====================================== */
 
@@ -313,9 +437,14 @@ scan_for_sensors(void)
 				}
 			sensor->path = g_strdup_printf("%s/%s%d", SENSORS_DIR,
 						       "in", id);
+			sensor->chip_class = lm78;
+			sensor->volt_order = n_volt_sensors++;
+			sensor->voltdefault = &voltdefault0[0];
+ 			sensor->voltdefaultsize =
+						sizeof (voltdefault0) / sizeof (VoltDefault);
 			sensor->offset = 0;
-			gkrellm_dup_string(&sensor->name, voltage_map[id].name);
-			sensor->factor = voltage_map[id].factor;
+			gkrellm_dup_string(&sensor->name, voltdefault0[id].name);
+			sensor->factor = voltdefault0[id].factor;
 			sensor_list = g_list_append(sensor_list, sensor);
 			}
 		}
@@ -374,6 +503,68 @@ get_linux_sensor(Sensor *sensor)
 	return TRUE;
 	}
 
+static void
+get_volt_default(gchar *chip_name, VoltDefault **vdf, gint *vdfsize,
+		ChipClass *chip)
+	{
+	if (!strncmp(chip_name, "it87", 4))
+		{
+		*chip = it87;
+		*vdf = &voltdefault8[0];
+		*vdfsize = sizeof (voltdefault8) / sizeof (VoltDefault);
+		}
+	else if (!strncmp(chip_name, "adm1025", 7))
+		{
+		*chip = adm1025;
+		*vdf = &voltdefault7[0];
+		*vdfsize = sizeof (voltdefault7) / sizeof (VoltDefault);
+		}
+	else if (!strncmp(chip_name, "mtp008", 6))
+		{
+		*chip = mtp008;
+		*vdf = &voltdefault6[0];
+		*vdfsize = sizeof (voltdefault6) / sizeof (VoltDefault);
+		}
+	else if (!strncmp(chip_name, "via686", 6))
+		{
+		*chip = via686;
+		*vdf = &voltdefault5[0];
+		*vdfsize = sizeof (voltdefault5) / sizeof (VoltDefault);
+		}
+	else if (!strncmp(chip_name, "gl520", 5))
+		{
+		*chip = gl520;
+		need_vref_config = TRUE;
+		*vdf = &voltdefault4[0];
+		*vdfsize = sizeof (voltdefault4) / sizeof (VoltDefault);
+		}
+	else if (!strncmp(chip_name, "gl518", 5))
+		{
+		*chip = gl518;
+		*vdf = &voltdefault3[0];
+		*vdfsize = sizeof (voltdefault3) / sizeof (VoltDefault);
+		}
+	else if (!strncmp(chip_name, "lm80", 4))
+		{
+		*chip = lm80;
+		need_vref_config = TRUE;
+		*vdf = &voltdefault2[0];
+		*vdfsize = sizeof (voltdefault2) / sizeof (VoltDefault);
+		}
+	else if (!strncmp(chip_name, "w83", 3) && strncmp(chip_name, "w83781", 6))
+		{
+		*chip = w83xxx;
+		*vdf = &voltdefault1[0];
+		*vdfsize = sizeof (voltdefault1) / sizeof (VoltDefault);
+		}
+	else
+		{
+		*chip = lm78;
+		*vdf = &voltdefault0[0];
+		*vdfsize = sizeof (voltdefault0) / sizeof (VoltDefault);
+		}
+	}
+
 
 static void
 scan_for_sensors(void)
@@ -382,9 +573,12 @@ scan_for_sensors(void)
 	struct dirent	*dentry;
 	FILE			*f, *f1;
 	Sensor			*sensor;
-	gint			n, type, divisor;
+	VoltDefault		*voltdefault;
+	ChipClass		chip;
+	gint			id = 0;
+	gint			type, divisor, voltdefaultsize, order_base;
 	gchar			*name;
-	gchar			path[256], fan_div[256], chip_name[128];
+	gchar			path[256], fan_div[256];
 
 	if ((dir = opendir(SENSORS_DIR)) == NULL)
 		return;
@@ -395,7 +589,8 @@ scan_for_sensors(void)
 		snprintf(path, sizeof(path), "%s/%s", SENSORS_DIR, dentry->d_name);
 		if ((chip_dir = opendir(path)) == NULL)
 			continue;
-		snprintf(chip_name, sizeof(chip_name), "%s", dentry->d_name);
+		order_base = n_volt_sensors;
+		get_volt_default(dentry->d_name, &voltdefault, &voltdefaultsize,&chip);
 		snprintf(fan_div, sizeof(fan_div), "%s/%s", path, "fan_div");
 		f = fopen(fan_div, "r");
 		while ((dentry = readdir(chip_dir)) != NULL)
@@ -408,7 +603,20 @@ scan_for_sensors(void)
 					)
 				type = SENSOR_FAN;
 			else if (!strncmp(name, "in", 2) && isdigit(name[2]))
+				{
 				type = SENSOR_VOLTAGE;
+				id = name[2] - '0';
+				}
+			else if (!strncmp(name, "vi", 2) && isdigit(name[3]))
+				{
+				type = SENSOR_VOLTAGE;
+				id = name[3] - '0';
+				}
+			else if (!strcmp(name, "vdd"))
+				{
+				type = SENSOR_VOLTAGE;
+				id = 0;
+				}
 			else
 				continue;
 
@@ -418,6 +626,7 @@ scan_for_sensors(void)
 			sensor->factor = 1.0;
 			sensor->offset = 0;
 			sensor->type = type;
+			sensor->chip_class = chip;
 			sensor_list = g_list_append(sensor_list, sensor);
 
 			if (type == SENSOR_FAN)
@@ -437,13 +646,19 @@ scan_for_sensors(void)
 				}
 			if (type == SENSOR_VOLTAGE)
 				{
-				n = name[2] - '0';
-				if (n < sizeof(voltage_map) / sizeof(struct _voltage_map))
+				++n_volt_sensors;
+				sensor->voltdefault = voltdefault;
+				sensor->voltdefaultsize = voltdefaultsize;
+				sensor->id = id;
+				sensor->volt_order = order_base + id;
+				if (id < voltdefaultsize)
 					{
-					sensor->id = n;
-					gkrellm_dup_string(&sensor->name, voltage_map[n].name);
-					sensor->factor = voltage_map[n].factor;
+					gkrellm_dup_string(&sensor->name, voltdefault[id].name);
+					sensor->factor = voltdefault[id].factor;
+					sensor->offset = voltdefault[id].offset;
 					}
+				else
+					gkrellm_dup_string(&sensor->name, name);
 				}
 			if (GK.debug_level & DEBUG_SENSORS)
 				printf("scan_for_sensors: %s %d\n",
@@ -459,9 +674,133 @@ scan_for_sensors(void)
 #endif  /* __linux__ */
 
 
+/* ----- NetBSD --------------------------------------------------------- */
+
+#if defined(__NetBSD__)
+
+/* The SENSORS_DIR is not defined as a directory, but directly points on
+ * the "sysmon" device, which implements envsys(4) API. This #define is
+ * not really useful for NetBSD since every sensor will use that device,
+ * but it still provides the location of the device inside the GUI. */
+#define SENSORS_DIR	"/dev/sysmon"
+
+#include <sys/envsys.h>
+
+/*
+ * scan_for_sensors -----------------------------------------------------
+ *
+ * At the moment, only two chips are supported: lm78 and alike (see
+ * lm(4)), and VT82C68A South Bridge for VIA chipsets (see viaenv(4)).
+ * Both support the envsys(4) API.
+ *
+ * XXX /dev/sysmon is opened but never closed. This is a problem since
+ * the driver wants an exclusive lock (e.g. envstat won't work when
+ * GKrellM will be running). But, at this time, I don't want to
+ * open/close sysmon each time a reading is needed. See README for
+ * details.
+ */
+
+static void
+scan_for_sensors(void)
+{
+   envsys_basic_info_t info;	/* sensor misc. info */
+   Sensor *sensor;		/* GKrellM sensor struct */
+   int fd;			/* file desc. for /dev/sysmon */
+   int id = 0;			/* incremented for each sensor */
+   char *s;
+
+   /* check if some sensor is configured */
+   fd = open(SENSORS_DIR, O_RDONLY); /* never closed :( */ 
+   if (fd < 0) return;
+
+   /* iterate through available sensors, until the first invalid */
+   for(info.sensor=0; ; info.sensor++) {
+
+      /* stop if we can't ioctl() */
+      if (ioctl(fd, ENVSYS_GTREINFO, &info) < 0) break;
+      /* stop if that sensor is not valid */
+      if (!(info.validflags & ENVSYS_FVALID)) break;
+
+      sensor = g_new0(Sensor, 1);
+      switch(info.units) {
+	 case ENVSYS_STEMP:
+	    sensor->type = SENSOR_TEMPERATURE;	break;
+	 case ENVSYS_SFANRPM:
+	    sensor->type = SENSOR_FAN;		break;
+	 case ENVSYS_SVOLTS_DC:
+	    sensor->type = SENSOR_VOLTAGE;		break;
+	 default:
+	    /* unwanted sensor type: continue */
+	    g_free(sensor);
+	    continue;
+      }
+
+      /* ok, we've got one working sensor */
+      sensor->iodev = fd;
+      sensor->interface = info.sensor;
+      sensor->id = id++;	
+
+      sensor->offset = 0.0;
+      sensor->factor = 1.0;
+
+      sensor->vref = NULL;
+      sensor->enabled = 1;
+      sensor->chip_class = lm78; /* there's no way to compute this */
+      sensor->volt_order = n_volt_sensors++;
+      sensor->voltdefault = &voltdefault0[0];
+      sensor->voltdefaultsize =
+	 sizeof (voltdefault0) / sizeof (VoltDefault);
+
+      sensor->path = g_strdup_printf("%s/%s", SENSORS_DIR, info.desc);
+      gkrellm_dup_string(&sensor->name, info.desc);
+      /* must map spaces into something else (for config file items) */
+      for(s=strchr(sensor->path, ' '); s != NULL; s=strchr(s, ' '))
+	 *s++ = '_';
+      for(s=strchr(sensor->name, ' '); s != NULL; s=strchr(s, ' '))
+	 *s++ = '_';
+
+      sensor_list = g_list_append(sensor_list, sensor);
+   }
+}
+
+
+/*
+ * get_netbsd_sensor ----------------------------------------------------
+ *
+ * Perform sensor reading
+ */
+
+static gboolean
+get_netbsd_sensor(Sensor *sensor)
+{
+   envsys_tre_data_t data;	/* sensor data */
+
+   data.sensor = sensor->interface;
+   if (ioctl(sensor->iodev, ENVSYS_GTREDATA, &data) < 0) return FALSE;
+   if (!(data.validflags & (ENVSYS_FVALID|ENVSYS_FCURVALID))) return FALSE;
+
+   switch(data.units) {
+      case ENVSYS_STEMP:	/* values in uK */
+	 sensor->value = (data.cur.data_us / 1.0e6) - 273.15/*0K*/ ;
+	 break;
+
+      case ENVSYS_SFANRPM:	/* values in RPM */
+	 sensor->value = data.cur.data_us;
+	 break;
+
+      default:			/* values in uV */
+	 sensor->value = data.cur.data_s / 1.0e6;
+	 break;
+   }
+
+   return TRUE;
+}
+
+#endif /* __NetBSD__ */
+
 
 /* ----- Other Systems -------------------------------------------------- */
-#if !defined(__FreeBSD__) && !defined(__linux__)
+#if !defined(__FreeBSD__) && !defined(__linux__) && !defined(__NetBSD__)
 
 #define	SENSORS_DIR		""
 
@@ -486,6 +825,13 @@ setup_sensor_interface(void)
 	get_voltage = get_linux_sensor;
 #endif
 
+#if defined(__NetBSD__)
+	scan_for_sensors();
+	get_temperature = get_netbsd_sensor;
+	get_fan = get_netbsd_sensor;
+	get_voltage = get_netbsd_sensor;
+#endif
+
 	return sensor_list ? TRUE : FALSE;
 	}
 
@@ -663,7 +1009,7 @@ get_mapped_sensor(gchar *name, gint sensor_type)
 	GList	*list;
 	Sensor	*sensor;
 
-	if (!name)
+	if (!name || !*name)
 		return NULL;
 	for (list = sensor_list; list; list = list->next)
 		{
@@ -693,6 +1039,34 @@ lookup_sensor_from_basename(gchar *basename)
 	return NULL;
 	}
 
+  /* Given a in0, in1, ... name as a reference to use for a sensor,
+  |  find the sensor with that name for the same chip as sr.
+  */
+static Sensor *
+lookup_vref(Sensor *sr, gchar *name)
+	{
+	GList	*list;
+	Sensor	*sv;
+	gchar	*s, buf[128];
+
+	snprintf(buf, 96, "%s", sensor_basename(sr->path));
+	s = strrchr(buf, '/');
+	if (s)
+		++s;
+	else
+		s = buf;
+	snprintf(s, 31, "%s", name);
+	for (list = sensor_list; list; list = list->next)
+		{
+		sv = (Sensor *) list->data;
+		if (   sv->type == SENSOR_VOLTAGE
+			&& !strcmp(sensor_basename(sv->path), buf)
+		   )
+			return sv;
+		}
+	return NULL;
+	}
+
 Alert *
 gkrellm_mapped_sensor_alert(gchar *name, gint sensor_type)
 	{
@@ -790,11 +1164,15 @@ static gboolean
 sensor_read_voltage(Sensor *sensor, gfloat *voltage)
 	{
 	gfloat	v = 0;
+	gfloat	offset;
 	gint	found_voltage = FALSE;
 
 	if (sensor && get_voltage && (*get_voltage)(sensor))
 		{
-		sensor->value = sensor->value * sensor->factor + sensor->offset;
+		offset = sensor->offset;
+		if (sensor->vref)	/* A negative voltage is level shifted by vref */
+			offset *= sensor->vref->value;
+		sensor->value = sensor->value * sensor->factor + offset;
 		v = sensor->value;
 		found_voltage = TRUE;
 		}
@@ -876,8 +1254,15 @@ static Sensor	*demo0_sensor, *demo1_sensor;
 static void
 add_volt_mon(Sensor *s)
 	{
-	VoltMon	*volt;
+	VoltMon		*volt;
+	VoltDefault	*vdf;
 
+	if (s->type == SENSOR_VOLTAGE)
+		{
+		vdf = &s->voltdefault[s->id];
+		if (!s->has_config && vdf->vref)
+			s->vref = lookup_vref(s, vdf->vref);
+		}
 	if (s->type != SENSOR_VOLTAGE || !s->enabled)
 		return;
 	volt = g_new0(VoltMon, 1);
@@ -885,12 +1270,41 @@ add_volt_mon(Sensor *s)
 	volt_list = g_list_append(volt_list, volt);
 	}
 
+  /* Verify config of volt orders has not been munged.
+  */
+static void
+check_volt_order(void)
+	{
+	GList	*list;
+	Sensor	*sr;
+	gint	i;
+
+	for (i = 0; i < n_volt_sensors; ++i)
+		{
+		for (list = sensor_list; list; list = list->next)
+			if (((Sensor *) list->data)->volt_order == i)
+				break;
+		if (!list)	/* Did not find an order number */
+			{
+			i = 0;
+			for (list = sensor_list; list; list = list->next)
+				{
+				sr = (Sensor *) list->data;
+				if (sr->type == SENSOR_VOLTAGE)
+					sr->volt_order = i++;
+				}
+			break;
+			}
+		}
+	}
+
 static void
 get_volt_list(void)
 	{
 	GList	*list;
 
 	free_glist_and_data(&volt_list);
+	check_volt_order();
 	for (list = sensor_list; list; list = list->next)
 		add_volt_mon((Sensor *) list->data);
 
@@ -901,13 +1315,20 @@ get_volt_list(void)
 		if (!demo0_sensor)
 			{
 			demo0_sensor = g_new0(Sensor, 1);
-			demo0_sensor->name = g_strdup(voltage_map[0].name);
+			demo0_sensor->name = g_strdup(voltdefault0[0].name);
 			demo0_sensor->type = SENSOR_VOLTAGE;
 			demo0_sensor->enabled = TRUE;
+			demo0_sensor->chip_class = lm78;
+			demo0_sensor->volt_order = demo0_sensor->id = 0;
+			demo0_sensor->voltdefault = &voltdefault0[0];
+			demo0_sensor->voltdefaultsize =
+					sizeof (voltdefault0) / sizeof (VoltDefault);
+
 			demo1_sensor = g_new0(Sensor, 1);
-			demo1_sensor->name = g_strdup(voltage_map[2].name);
-			demo1_sensor->type = SENSOR_VOLTAGE;
-			demo1_sensor->enabled = TRUE;
+			*demo1_sensor = *demo0_sensor;
+			demo1_sensor->name = g_strdup(voltdefault0[2].name);
+			demo1_sensor->volt_order = demo1_sensor->id = 1;
+			n_volt_sensors = 2;
 			}
 		add_volt_mon(demo0_sensor);
 		add_volt_mon(demo1_sensor);
@@ -943,6 +1364,7 @@ static gboolean
 any_negative_volts(void)
 	{
 	GList		*list;
+	Sensor		*s;
 	VoltMon		*volt;
 	gfloat		v;
 
@@ -953,6 +1375,9 @@ any_negative_volts(void)
 		{
 		volt = (VoltMon *) list->data;
 		gkrellm_freeze_alert(volt->sensor->alert);
+		s = volt->sensor->vref;
+		if (s && s->value == 0)
+			sensor_read_voltage(s, &v);
 		sensor_read_voltage(volt->sensor, &v);
 		gkrellm_thaw_alert(volt->sensor->alert);
 		if (v < 0.0)
@@ -961,10 +1386,48 @@ any_negative_volts(void)
 	return FALSE;
 	}
 
+static VoltMon *
+voltmon_first(void)
+	{
+	GList	*list;
+	VoltMon	*volt = NULL;
+	VoltMon	*vtest;
+
+	for (list = volt_list; list; list = list->next)
+		{
+		vtest = (VoltMon *) list->data;
+		if (!volt)
+			volt = vtest;
+		else if (volt->sensor->volt_order > vtest->sensor->volt_order)
+			volt = vtest;
+		}
+	return volt;
+	}
+
+static VoltMon *
+voltmon_next(VoltMon *vcur)
+	{
+	GList	*list;
+	VoltMon	*volt = NULL;
+	VoltMon	*vtest;
+
+	for (list = volt_list; list; list = list->next)
+		{
+		vtest = (VoltMon *) list->data;
+		if (vtest->sensor->volt_order > vcur->sensor->volt_order)
+			{
+			if (!volt)
+				volt = vtest;
+			else if (vtest->sensor->volt_order < volt->sensor->volt_order)
+				volt = vtest;
+			}
+		}
+	return volt;
+	}
+
 static void
 make_volt_decals(Panel *p, Style *style)
 	{
-	GList			*list;
 	GdkImlibBorder	*b		= &bezel_style->border;
 	VoltMon			*volt;
 	Decal			*dv, *dn;
@@ -990,10 +1453,8 @@ make_volt_decals(Panel *p, Style *style)
 		fmt = "-8.88";
 		}
 
-	for (list = volt_list; list; list = list->next)
+	for (volt = voltmon_first(); volt; volt = voltmon_next(volt))
 		{
-		volt = (VoltMon *) list->data;
-
 		if (display_mode == DIGITAL_WITH_LABELS)
 			{
 			volt->name_decal = dn = gkrellm_create_decal_text(p,
@@ -1027,7 +1488,6 @@ make_volt_decals(Panel *p, Style *style)
 static void
 layout_volt_decals(Panel *p, Style *style)
 	{
-	GList	*list;
 	VoltMon	*volt;
 	Decal	*dv, *dn;
 	gint	x, y, w, c, n, cols;
@@ -1044,9 +1504,8 @@ layout_volt_decals(Panel *p, Style *style)
 		
 	gkrellm_get_top_bottom_margins(style, &y, NULL);
 	c = 0;
-	for (list = volt_list; list; list = list->next)
+	for (volt = voltmon_first(); volt; volt = voltmon_next(volt))
 		{
-		volt = (VoltMon *) list->data;
 		dn = volt->name_decal;
 		dv = volt->volt_decal;
 		/* Right justify the volt decal in each volt_mon field
@@ -1078,6 +1537,7 @@ draw_voltages(gint do_names)
 	{
 	GList		*list;
 	VoltMon		*volt;
+	Sensor		*sensor;
 	Decal		*d;
 	gchar		*fmt, buf[32];
 	gfloat		v;
@@ -1085,12 +1545,16 @@ draw_voltages(gint do_names)
 	for (list = volt_list; list; list = list->next)
 		{
 		volt = (VoltMon *) list->data;
+		sensor = volt->sensor;
+		sensor->value_valid = FALSE;
 		if (do_names && volt->name_decal)
-			gkrellm_draw_decal_text(pVolt, volt->name_decal,
-					volt->sensor->name, -1);
+			gkrellm_draw_decal_text(pVolt, volt->name_decal, sensor->name, -1);
 		if ((d = volt->volt_decal) != NULL)
 			{
-			sensor_read_voltage(volt->sensor, &v);
+			if (sensor->vref && !sensor->vref->value_valid)
+				sensor_read_voltage(sensor->vref, NULL);
+			sensor_read_voltage(sensor, &v);
+			sensor->value_valid = TRUE;
 			if ((v < 10.0 && v > 0.0) || (v > -10.0 && v < 0.0))
 				fmt = "%.2f";
 			else
@@ -1309,15 +1773,23 @@ save_sensors_config(FILE *f)
 	for (list = sensor_list; list; list = list->next)
 		{
 		s = (Sensor *) list->data;
-		if (s->name && *(s->name) != '\0')
+		if (s->name && *(s->name))
 			{
-			fprintf(f, "%s %s %s %f %f %d\n", SENSOR_CONFIG_KEYWORD, s->name,
-				sensor_basename(s->path), s->factor, s->offset, s->enabled);
+			fprintf(f, "%s %s %s %.4f %.4f %d %d\n", SENSOR_CONFIG_KEYWORD,
+				s->name, sensor_basename(s->path),
+				s->factor, s->offset, s->enabled, s->volt_order);
 			if (s->alert)
 				gkrellm_save_alertconfig(f, s->alert,
 						SENSOR_CONFIG_KEYWORD, sensor_basename(s->path));
 			}
 		}
+	for (list = sensor_list; list; list = list->next)
+		{
+		s = (Sensor *) list->data;
+		if (s->vref)
+			fprintf(f, "%s vref %s %s\n", SENSOR_CONFIG_KEYWORD,
+					sensor_basename(s->path), sensor_basename(s->vref->path));
+		}
 	fprintf(f, "%s units_fahrenheit %d\n", SENSOR_CONFIG_KEYWORD,
 				units_fahrenheit);
 	fprintf(f, "%s volt_display_mode %d\n", SENSOR_CONFIG_KEYWORD,
@@ -1329,24 +1801,31 @@ load_sensors_config(gchar *arg)
 	{
 	Sensor	*s;
 	gchar	config[32], item[CFG_BUFSIZE], item1[CFG_BUFSIZE];
-	gchar	name[32], sensor_name[CFG_BUFSIZE];
+	gchar	name[64], sensor_name[CFG_BUFSIZE];
 	gint	n;
 	gfloat	f	= 1.0,
 			o	= 0.0;
-	gint	e	= 0;
+	gint	e	= 0,
+			order= -1;
 
 	n = sscanf(arg, "%31s %[^\n]", config, item);
 	if (n != 2)
 		return;
 	if (GK.debug_level & DEBUG_SENSORS)
 		printf("load_sensors_config: <%s> <%s>\n", config, item);
-	if (strcmp(config, "units_fahrenheit") == 0)
+	if (!strcmp(config, "units_fahrenheit"))
 		sscanf(item, "%d", &units_fahrenheit);
-	if (strcmp(config, "volt_display_mode") == 0)
+	else if (!strcmp(config, "volt_display_mode"))
 		sscanf(item, "%d", &display_mode);
+	else if (!strcmp(config, "vref"))
+		{
+		sscanf(item, "%63s %63s", name, item1);
+		s = lookup_sensor_from_basename(name);
+		s->vref = lookup_sensor_from_basename(item1);
+		}
 	else if (!strcmp(config, GKRELLM_ALERTCONFIG_KEYWORD))
 		{
-		n = sscanf(item, "%31s %[^\n]", name, item1);
+		n = sscanf(item, "%63s %[^\n]", name, item1);
 		s = lookup_sensor_from_basename(name);
 		if (s && n == 2)
 			{
@@ -1355,14 +1834,17 @@ load_sensors_config(gchar *arg)
 			gkrellm_load_alertconfig(&s->alert, item1);
 			}
 		}
-	else if (   sscanf(arg, "%31s %s %f %f %d",
-						name, sensor_name, &f, &o, &e) > 1
+	else if (   sscanf(arg, "%63s %s %f %f %d %d",
+						name, sensor_name, &f, &o, &e, &order) > 1
 			 && (s = map_sensor_name(name, sensor_name)) != NULL
 			)
 		{
 		s->factor = f;
 		s->offset = o;
 		s->enabled = e;
+		if (s->type == SENSOR_VOLTAGE && order >= 0)
+			s->volt_order = order;
+		s->has_config = TRUE;
 		}
 	if (display_mode < 0 || display_mode >= N_DISPLAY_MODES)
 		display_mode = N_DISPLAY_MODES - 1;
@@ -1431,9 +1913,11 @@ apply_sensors_config(void)
 		if (s->entry)
 			{
 			name = gkrellm_entry_get_text(&s->entry);
-			if (!*name && s->type == SENSOR_VOLTAGE)
+			if (   !*name && s->type == SENSOR_VOLTAGE
+				&& s->id < s->voltdefaultsize
+			   )
 				{
-				name = voltage_map[s->id].name;
+				name = s->voltdefault[s->id].name;
 				gtk_entry_set_text(GTK_ENTRY(s->entry), name);
 				gtk_label_set_text(
 						GTK_LABEL(GTK_BIN(s->select_button)->child), name);
@@ -1453,6 +1937,13 @@ apply_sensors_config(void)
 					}
 				}
 			}
+		if (s->vref_entry)
+			{
+			name = gkrellm_entry_get_text(&s->vref_entry);
+			s->vref = lookup_vref(s, name);
+			gtk_entry_set_text(GTK_ENTRY(s->vref_entry),
+						s->vref ? g_basename(s->vref->path) : "");
+			}
 		if (s->factor_spin_button)
 			s->factor = gtk_spin_button_get_value_as_float(
 						GTK_SPIN_BUTTON(s->factor_spin_button));
@@ -1466,6 +1957,28 @@ apply_sensors_config(void)
 		   )
 			fix_temp_alert(s);
 		}
+
+	/* Temp and fan labels must be unique */
+	for (list = sensor_list; list; list = list->next)
+		{
+		s = (Sensor *) list->data;
+		if (s->type != SENSOR_TEMPERATURE && s->type != SENSOR_FAN)
+			continue;
+		if (*(s->name) && s != (Sensor *) get_mapped_sensor(s->name, s->type))
+			{
+			gkrellm_dup_string(&s->name, "");
+			if (s->entry)
+				gtk_entry_set_text(GTK_ENTRY(s->entry), s->name);
+			if (s->alert)
+				{
+				gkrellm_alert_destroy(&s->alert);
+				set_alert_button_state(s);
+				}
+			gkrellm_message_window(_("GKrellM Config Error"),
+				_("Duplicate label for either a temperature or fan"), NULL);
+			}
+		}
+
 	previous = display_mode;
 	for (i = 0; i < N_DISPLAY_MODES; ++i)
 		if (GTK_TOGGLE_BUTTON(display_mode_button[i])->active)
@@ -1512,6 +2025,43 @@ cb_volt_entry(GtkWidget *entry, Sensor *voltage)
 				GTK_LABEL(GTK_BIN(voltage->select_button)->child), name);
 	}
 
+static void
+cb_vref_entry(GtkWidget *entry, gpointer data)
+	{
+	voltages_modified = TRUE;
+	}
+
+static void
+cb_volt_order(GtkWidget *button, Sensor *sv)
+	{
+	GtkSpinButton	*spin;
+	GList			*list;
+	Sensor			*sr;
+	gint			order, replaced_order;
+
+	voltages_modified = TRUE;
+	spin = GTK_SPIN_BUTTON(sv->volt_order_spin_button);
+	order = gtk_spin_button_get_value_as_int(spin);
+	if (order == sv->volt_order)
+		return;
+	replaced_order = sv->volt_order;
+	sv->volt_order = order;
+
+	for (list = sensor_list; list; list = list->next)
+		{
+		sr = (Sensor *) list->data;
+		if (sr->type != SENSOR_VOLTAGE || sr == sv)
+			continue;
+		if (sr->volt_order == sv->volt_order)
+			{
+			sr->volt_order = replaced_order;
+			spin = GTK_SPIN_BUTTON(sr->volt_order_spin_button);
+			gtk_spin_button_set_value(spin, (gfloat) sr->volt_order);
+			break;
+			}
+		}
+	}
+
 static void
 cb_sensor_alert_config(Alert *alert, Sensor *sensor)
 	{
@@ -1556,7 +2106,11 @@ N_("The second function of the Setup page is to assign data scaling factors\n"
 "read the GKrellM README and lm_sensor documetation for more info.  Note\n"
 "that wherever documentation refers to possible fan divisors of 2, the\n"
 "correct entry here would be a fan factor of 0.5.  Also, any temperature\n"
-"Sensor Correction Offset values must be in centigrade units.\n")
+"Sensor Correction Offset values must be in centigrade units.\n"),
+"\n",
+N_("There will be a Vref entry for negative voltages if you have a sensor\n"
+"chip that uses an external voltage reference for level shifting negative\n"
+"input voltages (such as the lm80).  See the README or do a man gkrellm.\n")
 	};
 
 static gchar *sensor_name_set[4] =
@@ -1574,7 +2128,7 @@ create_sensors_tab(GtkWidget *tab_vbox)
 	GtkWidget	*table;
 	GtkWidget	*button;
 	GtkWidget	*text;
-	GtkWidget	*vbox, *vbox1, *hbox, *box;
+	GtkWidget	*vbox, *vbox1, *hbox, *hbox1, *box;
 	GtkWidget	*label;
 	GtkWidget	*entry;
 	GList		*list;
@@ -1589,7 +2143,7 @@ create_sensors_tab(GtkWidget *tab_vbox)
 /* --Setup tab */
 	vbox = gkrellm_create_framed_tab(tabs, _("Setup"));
 
-	table = gtk_table_new(2, 5, FALSE);
+	table = gtk_table_new(2, 6, FALSE);
 	gtk_table_set_col_spacings(GTK_TABLE(table), 0);
 	gtk_box_pack_start(GTK_BOX(vbox), table, FALSE, FALSE, 3);
 
@@ -1609,8 +2163,13 @@ create_sensors_tab(GtkWidget *tab_vbox)
 	gtk_table_attach_defaults(GTK_TABLE(table), label, 2, 3, 1, 2);
 	label = gtk_label_new(_("Offset"));
 	gtk_table_attach_defaults(GTK_TABLE(table), label, 3, 4, 1, 2);
+	if (need_vref_config)
+		{
+		label = gtk_label_new(_("Vref"));
+		gtk_table_attach_defaults(GTK_TABLE(table), label, 4, 5, 1, 2);
+		}
 	label = gtk_label_new(_("Alerts"));
-	gtk_table_attach_defaults(GTK_TABLE(table), label, 4, 5, 1, 2);
+	gtk_table_attach_defaults(GTK_TABLE(table), label, 5, 6, 1, 2);
 
 	box = gkrellm_scrolled_vbox(vbox, NULL,
 			GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
@@ -1650,8 +2209,23 @@ create_sensors_tab(GtkWidget *tab_vbox)
 			gtk_signal_connect(GTK_OBJECT(sr->offset_spin_button), "changed",
 					(GtkSignalFunc) cb_correction_modified, NULL);
 			}
+		if (   sr->type == SENSOR_VOLTAGE
+			&& (   (sr->chip_class == gl520 && sr->id == 4)
+				|| (sr->chip_class == lm80 && (sr->id == 5 || sr->id == 6))
+			   )
+		   )
+			{	/* These chips use a Vref for their negative inputs.	*/
+			entry = gtk_entry_new_with_max_length(8);
+			sr->vref_entry = entry;
+			gtk_entry_set_text(GTK_ENTRY(entry),
+						sr->vref ? g_basename(sr->vref->path) : "");
+			gtk_widget_set_usize(entry, 36, 0);
+			gtk_table_attach_defaults(GTK_TABLE(table), entry, 4, 5, i, i + 1);
+			gtk_signal_connect(GTK_OBJECT(entry), "changed",
+						(GtkSignalFunc) cb_vref_entry, NULL);
+			}
 		box = gtk_hbox_new(FALSE, 0);
-		gtk_table_attach_defaults(GTK_TABLE(table), box, 4, 5, i, i+1);
+		gtk_table_attach_defaults(GTK_TABLE(table), box, 5, 6, i, i+1);
 		gkrellm_button_connected(box, &sr->alert_button, TRUE, TRUE, 10,
 				cb_sensor_set_alert, sr, "");
 		set_alert_button_state(sr);
@@ -1661,7 +2235,7 @@ create_sensors_tab(GtkWidget *tab_vbox)
 
 /* --Voltages tab */
 	vbox = gkrellm_create_framed_tab(tabs, _("Voltages"));
-	hbox = gtk_hbox_new (TRUE, 0);	
+	hbox = gtk_hbox_new(TRUE, 0);
 	gtk_container_add(GTK_CONTAINER(vbox), hbox);
 
 	vbox1 = gkrellm_framed_vbox(hbox, _("Select"), 4, TRUE, 0, 2);
@@ -1682,8 +2256,13 @@ create_sensors_tab(GtkWidget *tab_vbox)
 			dirname = NULL;
 			box = gkrellm_framed_vbox(vbox1, chipname, 4, TRUE, 0, 2);
 			}
-		gkrellm_check_button_connected(box, &sr->select_button, sr->enabled,
-					FALSE, FALSE, 0, cb_volt_enabled, sr, sr->name);
+		hbox1 = gtk_hbox_new(TRUE, 0);
+		gtk_box_pack_start(GTK_BOX(box), hbox1, FALSE, FALSE, 0);
+		gkrellm_check_button_connected(hbox1, &sr->select_button, sr->enabled,
+				TRUE, TRUE, 0, cb_volt_enabled, sr, sr->name);
+		gkrellm_spin_button(hbox1, &sr->volt_order_spin_button, sr->volt_order,
+				0, n_volt_sensors - 1, 1.0, 1.0, 0, 40,
+				cb_volt_order, sr, FALSE, NULL);
 		}
 	if (chipname)
 		g_free(chipname);
