@@ -20,7 +20,8 @@
 
 /*
 |  4/22/2001  Solaris code contributed by Daisuke Yabuki <dxy@acm.org>
-| 10/12/2000  NetBSD code contributed by Anthony Mallet <metall@ficus.yi.org>
+| 10/12/2000  NetBSD code contributed by Anthony Mallet
+|		<anthony.mallet@useless-ficus.net> 
 |  2/25/2000  FreeBSD code contributed by Hajimu UMEMOTO ume@mahoroba.org
 */
 
