@@ -21,6 +21,8 @@
 #include "gkrellm.h"
 
 #include <pwd.h>
+#include <errno.h>
+#include <sys/wait.h>
 
 
 /* ===============  string utility functions ================= */
@@ -51,9 +53,11 @@ dup_string(gchar **dst, gchar *src)
 gboolean
 gkrellm_dup_string(gchar **dst, gchar *src)
 	{
+	if (!*dst && !src)
+		return FALSE;
 	if (*dst)
 		{
-		if (!strcmp(*dst, src))
+		if (src && !strcmp(*dst, src))
 			return FALSE;
 		g_free(*dst);
 		}
@@ -61,6 +65,16 @@ gkrellm_dup_string(gchar **dst, gchar *src)
 	return TRUE;
 	}
 
+void
+gkrellm_free_pixmap(GdkPixmap **pixmap)
+	{
+	if (!pixmap)
+		return;
+	if (*pixmap)
+		gdk_imlib_free_pixmap(*pixmap);
+	*pixmap = NULL;
+	}
+
   /* Cut out an optionally quoted string.  This is destructive to the src.
   */
 gchar *
@@ -329,3 +343,55 @@ locale_float_fix(gchar *s)
 		v += atof(ibuf);
 	return v;
 	}
+
+
+  /* Need a system() call that closes all open files (except stdin, stdout,
+  |  and stderr) in the child process.
+  */
+gint
+gkrellm_system(gchar *cmd)
+	{
+	pid_t	pid, child_pid;
+	gint	fd, max_open, status = -1;
+
+	if (!cmd)
+		return status;
+	pid = fork();
+	if (pid == (pid_t) 0)
+		{	/* Child */
+#if defined(_SC_OPEN_MAX)
+		max_open = sysconf(_SC_OPEN_MAX);
+#elif defined (_NFILE)
+		max_open = _NFILE;
+#else
+		max_open = 40;
+#endif
+		for (fd = 3; fd < max_open; ++fd)
+			close(fd);
+		system(cmd);
+		_exit(0);
+		}
+	else if (pid > (pid_t) 0)
+		{	/* Parent */
+#if defined(WNOHANG) && defined(WUNTRACED)
+		do
+			child_pid = waitpid(pid, &status, 0);
+		while (child_pid == (pid_t) -1 && errno == EINTR);
+
+		if (child_pid != pid)
+			status = -1;
+#else
+		do
+			{
+			child_pid = wait(&status);
+			if (child_pid <= -1 && errno != EINTR)
+				{
+				status = -1;
+				break;
+				}
+			}
+		while (child_pid != pid);
+#endif
+		}
+	return status;
+	}
